/******************************************************************************
*
* Copyright (C) 2016 - 2018 Xilinx, Inc.  All rights reserved.
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
* THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
* THE SOFTWARE.
*
*
*
******************************************************************************/
/*****************************************************************************/
/**
*
* @file xsysmonpsv_hw.h
* @addtogroup sysmonpsv_v1_1
*
* This header file contains the identifiers and basic driver functions (or
* macros) that can be used to access the device. Other driver functions
* are defined in xsysmonpsv.h.
*
* <pre>
* MODIFICATION HISTORY:
*
* Ver   Who    Date	Changes
* ----- -----  -------- -----------------------------------------------
* 1.0   aad    11/09/18 First release
* 1.1   aad    07/11/19 Fixed NEW_DATA_MASK
*
* </pre>
*
******************************************************************************/

#ifndef XSYSMONPSV_HW_H_
#define XSYSMONPSV_HW_H_

#ifdef __cplusplus
extern "C" {
#endif

/***************************** Include Files ********************************/

#include "xil_io.h"

/**
 * XSYSMONPSV Base Address
 */
#define XSYSMONPSV_BASEADDR      0XF1270000

/**
 * Register: XSYSMONPSV_PCSR_MASK
 */
#define XSYSMONPSV_PCSR_MASK     0X00000000

#define XSYSMONPSV_PCSR_MASK_SPARE_SHIFT   25
#define XSYSMONPSV_PCSR_MASK_SPARE_WIDTH   7
#define XSYSMONPSV_PCSR_MASK_SPARE_MASK    0XFE000000

#define XSYSMONPSV_PCSR_MASK_SECURE_EFUSE_START_SHIFT   24
#define XSYSMONPSV_PCSR_MASK_SECURE_EFUSE_START_WIDTH   1
#define XSYSMONPSV_PCSR_MASK_SECURE_EFUSE_START_MASK    0X01000000

#define XSYSMONPSV_PCSR_MASK_PCSR_RESERVED_SHIFT   21
#define XSYSMONPSV_PCSR_MASK_PCSR_RESERVED_WIDTH   3
#define XSYSMONPSV_PCSR_MASK_PCSR_RESERVED_MASK    0X00E00000

#define XSYSMONPSV_PCSR_MASK_TEST_SAFE_SHIFT   20
#define XSYSMONPSV_PCSR_MASK_TEST_SAFE_WIDTH   1
#define XSYSMONPSV_PCSR_MASK_TEST_SAFE_MASK    0X00100000

#define XSYSMONPSV_PCSR_MASK_SLVERREN_SHIFT   19
#define XSYSMONPSV_PCSR_MASK_SLVERREN_WIDTH   1
#define XSYSMONPSV_PCSR_MASK_SLVERREN_MASK    0X00080000

#define XSYSMONPSV_PCSR_MASK_MEM_CLEAR_TRIGGER_SHIFT   18
#define XSYSMONPSV_PCSR_MASK_MEM_CLEAR_TRIGGER_WIDTH   1
#define XSYSMONPSV_PCSR_MASK_MEM_CLEAR_TRIGGER_MASK    0X00040000

#define XSYSMONPSV_PCSR_MASK_SYS_RST_MASK_SHIFT   15
#define XSYSMONPSV_PCSR_MASK_SYS_RST_MASK_WIDTH   3
#define XSYSMONPSV_PCSR_MASK_SYS_RST_MASK_MASK    0X00038000

#define XSYSMONPSV_PCSR_MASK_PWRDN_SHIFT   14
#define XSYSMONPSV_PCSR_MASK_PWRDN_WIDTH   1
#define XSYSMONPSV_PCSR_MASK_PWRDN_MASK    0X00004000

#define XSYSMONPSV_PCSR_MASK_DISNPICLK_SHIFT   13
#define XSYSMONPSV_PCSR_MASK_DISNPICLK_WIDTH   1
#define XSYSMONPSV_PCSR_MASK_DISNPICLK_MASK    0X00002000

#define XSYSMONPSV_PCSR_MASK_APBEN_SHIFT   12
#define XSYSMONPSV_PCSR_MASK_APBEN_WIDTH   1
#define XSYSMONPSV_PCSR_MASK_APBEN_MASK    0X00001000

#define XSYSMONPSV_PCSR_MASK_SCAN_CLEAR_TRIGGER_SHIFT   11
#define XSYSMONPSV_PCSR_MASK_SCAN_CLEAR_TRIGGER_WIDTH   1
#define XSYSMONPSV_PCSR_MASK_SCAN_CLEAR_TRIGGER_MASK    0X00000800

#define XSYSMONPSV_PCSR_MASK_STARTCAL_SHIFT   10
#define XSYSMONPSV_PCSR_MASK_STARTCAL_WIDTH   1
#define XSYSMONPSV_PCSR_MASK_STARTCAL_MASK    0X00000400

#define XSYSMONPSV_PCSR_MASK_FABRICEN_SHIFT   9
#define XSYSMONPSV_PCSR_MASK_FABRICEN_WIDTH   1
#define XSYSMONPSV_PCSR_MASK_FABRICEN_MASK    0X00000200

#define XSYSMONPSV_PCSR_MASK_TRISTATE_SHIFT   8
#define XSYSMONPSV_PCSR_MASK_TRISTATE_WIDTH   1
#define XSYSMONPSV_PCSR_MASK_TRISTATE_MASK    0X00000100

#define XSYSMONPSV_PCSR_MASK_HOLDSTATE_SHIFT   7
#define XSYSMONPSV_PCSR_MASK_HOLDSTATE_WIDTH   1
#define XSYSMONPSV_PCSR_MASK_HOLDSTATE_MASK    0X00000080

#define XSYSMONPSV_PCSR_MASK_INITSTATE_SHIFT   6
#define XSYSMONPSV_PCSR_MASK_INITSTATE_WIDTH   1
#define XSYSMONPSV_PCSR_MASK_INITSTATE_MASK    0X00000040

#define XSYSMONPSV_PCSR_MASK_ODISABLE_SHIFT   2
#define XSYSMONPSV_PCSR_MASK_ODISABLE_WIDTH   4
#define XSYSMONPSV_PCSR_MASK_ODISABLE_MASK    0X0000003C

#define XSYSMONPSV_PCSR_MASK_GATEREG_SHIFT   1
#define XSYSMONPSV_PCSR_MASK_GATEREG_WIDTH   1
#define XSYSMONPSV_PCSR_MASK_GATEREG_MASK    0X00000002

#define XSYSMONPSV_PCSR_MASK_PCOMPLETE_SHIFT   0
#define XSYSMONPSV_PCSR_MASK_PCOMPLETE_WIDTH   1
#define XSYSMONPSV_PCSR_MASK_PCOMPLETE_MASK    0X00000001

/**
 * Register: XSYSMONPSV_PCSR_CONTROL
 */
#define XSYSMONPSV_PCSR_CONTROL     0X00000004

#define XSYSMONPSV_PCSR_CONTROL_SPARE_SHIFT   25
#define XSYSMONPSV_PCSR_CONTROL_SPARE_WIDTH   7
#define XSYSMONPSV_PCSR_CONTROL_SPARE_MASK    0XFE000000

#define XSYSMONPSV_PCSR_CONTROL_SECURE_EFUSE_START_SHIFT   24
#define XSYSMONPSV_PCSR_CONTROL_SECURE_EFUSE_START_WIDTH   1
#define XSYSMONPSV_PCSR_CONTROL_SECURE_EFUSE_START_MASK    0X01000000

#define XSYSMONPSV_PCSR_CONTROL_PCSR_RESERVED_SHIFT   21
#define XSYSMONPSV_PCSR_CONTROL_PCSR_RESERVED_WIDTH   3
#define XSYSMONPSV_PCSR_CONTROL_PCSR_RESERVED_MASK    0X00E00000

#define XSYSMONPSV_PCSR_CONTROL_TEST_SAFE_SHIFT   20
#define XSYSMONPSV_PCSR_CONTROL_TEST_SAFE_WIDTH   1
#define XSYSMONPSV_PCSR_CONTROL_TEST_SAFE_MASK    0X00100000

#define XSYSMONPSV_PCSR_CONTROL_SLVERREN_SHIFT   19
#define XSYSMONPSV_PCSR_CONTROL_SLVERREN_WIDTH   1
#define XSYSMONPSV_PCSR_CONTROL_SLVERREN_MASK    0X00080000

#define XSYSMONPSV_PCSR_CONTROL_MEM_CLEAR_TRIGGER_SHIFT   18
#define XSYSMONPSV_PCSR_CONTROL_MEM_CLEAR_TRIGGER_WIDTH   1
#define XSYSMONPSV_PCSR_CONTROL_MEM_CLEAR_TRIGGER_MASK    0X00040000

#define XSYSMONPSV_PCSR_CONTROL_SYS_RST_MASK_SHIFT   15
#define XSYSMONPSV_PCSR_CONTROL_SYS_RST_MASK_WIDTH   3
#define XSYSMONPSV_PCSR_CONTROL_SYS_RST_MASK_MASK    0X00038000

#define XSYSMONPSV_PCSR_CONTROL_PWRDN_SHIFT   14
#define XSYSMONPSV_PCSR_CONTROL_PWRDN_WIDTH   1
#define XSYSMONPSV_PCSR_CONTROL_PWRDN_MASK    0X00004000

#define XSYSMONPSV_PCSR_CONTROL_DISNPICLK_SHIFT   13
#define XSYSMONPSV_PCSR_CONTROL_DISNPICLK_WIDTH   1
#define XSYSMONPSV_PCSR_CONTROL_DISNPICLK_MASK    0X00002000

#define XSYSMONPSV_PCSR_CONTROL_APBEN_SHIFT   12
#define XSYSMONPSV_PCSR_CONTROL_APBEN_WIDTH   1
#define XSYSMONPSV_PCSR_CONTROL_APBEN_MASK    0X00001000

#define XSYSMONPSV_PCSR_CONTROL_SCAN_CLEAR_TRIGGER_SHIFT   11
#define XSYSMONPSV_PCSR_CONTROL_SCAN_CLEAR_TRIGGER_WIDTH   1
#define XSYSMONPSV_PCSR_CONTROL_SCAN_CLEAR_TRIGGER_MASK    0X00000800

#define XSYSMONPSV_PCSR_CONTROL_STARTCAL_SHIFT   10
#define XSYSMONPSV_PCSR_CONTROL_STARTCAL_WIDTH   1
#define XSYSMONPSV_PCSR_CONTROL_STARTCAL_MASK    0X00000400

#define XSYSMONPSV_PCSR_CONTROL_FABRICEN_SHIFT   9
#define XSYSMONPSV_PCSR_CONTROL_FABRICEN_WIDTH   1
#define XSYSMONPSV_PCSR_CONTROL_FABRICEN_MASK    0X00000200

#define XSYSMONPSV_PCSR_CONTROL_TRISTATE_SHIFT   8
#define XSYSMONPSV_PCSR_CONTROL_TRISTATE_WIDTH   1
#define XSYSMONPSV_PCSR_CONTROL_TRISTATE_MASK    0X00000100

#define XSYSMONPSV_PCSR_CONTROL_HOLDSTATE_SHIFT   7
#define XSYSMONPSV_PCSR_CONTROL_HOLDSTATE_WIDTH   1
#define XSYSMONPSV_PCSR_CONTROL_HOLDSTATE_MASK    0X00000080

#define XSYSMONPSV_PCSR_CONTROL_INITSTATE_SHIFT   6
#define XSYSMONPSV_PCSR_CONTROL_INITSTATE_WIDTH   1
#define XSYSMONPSV_PCSR_CONTROL_INITSTATE_MASK    0X00000040

#define XSYSMONPSV_PCSR_CONTROL_ODISABLE_SHIFT   2
#define XSYSMONPSV_PCSR_CONTROL_ODISABLE_WIDTH   4
#define XSYSMONPSV_PCSR_CONTROL_ODISABLE_MASK    0X0000003C

#define XSYSMONPSV_PCSR_CONTROL_GATEREG_SHIFT   1
#define XSYSMONPSV_PCSR_CONTROL_GATEREG_WIDTH   1
#define XSYSMONPSV_PCSR_CONTROL_GATEREG_MASK    0X00000002

#define XSYSMONPSV_PCSR_CONTROL_PCOMPLETE_SHIFT   0
#define XSYSMONPSV_PCSR_CONTROL_PCOMPLETE_WIDTH   1
#define XSYSMONPSV_PCSR_CONTROL_PCOMPLETE_MASK    0X00000001

/**
 * Register: XSYSMONPSV_PCSR_STATUS
 */
#define XSYSMONPSV_PCSR_STATUS     0X00000008

#define XSYSMONPSV_PCSR_STATUS_HARD_FAIL_OR_SHIFT   11
#define XSYSMONPSV_PCSR_STATUS_HARD_FAIL_OR_WIDTH   3
#define XSYSMONPSV_PCSR_STATUS_HARD_FAIL_OR_MASK    0X00003800

#define XSYSMONPSV_PCSR_STATUS_HARD_FAIL_AND_SHIFT   8
#define XSYSMONPSV_PCSR_STATUS_HARD_FAIL_AND_WIDTH   3
#define XSYSMONPSV_PCSR_STATUS_HARD_FAIL_AND_MASK    0X00000700

#define XSYSMONPSV_PCSR_STATUS_MEM_CLEAR_PASS_SHIFT   7
#define XSYSMONPSV_PCSR_STATUS_MEM_CLEAR_PASS_WIDTH   1
#define XSYSMONPSV_PCSR_STATUS_MEM_CLEAR_PASS_MASK    0X00000080

#define XSYSMONPSV_PCSR_STATUS_MEM_CLEAR_DONE_SHIFT   6
#define XSYSMONPSV_PCSR_STATUS_MEM_CLEAR_DONE_WIDTH   1
#define XSYSMONPSV_PCSR_STATUS_MEM_CLEAR_DONE_MASK    0X00000040

#define XSYSMONPSV_PCSR_STATUS_CALERROR_SHIFT   5
#define XSYSMONPSV_PCSR_STATUS_CALERROR_WIDTH   1
#define XSYSMONPSV_PCSR_STATUS_CALERROR_MASK    0X00000020

#define XSYSMONPSV_PCSR_STATUS_CALDONE_SHIFT   4
#define XSYSMONPSV_PCSR_STATUS_CALDONE_WIDTH   1
#define XSYSMONPSV_PCSR_STATUS_CALDONE_MASK    0X00000010

#define XSYSMONPSV_PCSR_STATUS_INCAL_SHIFT   3
#define XSYSMONPSV_PCSR_STATUS_INCAL_WIDTH   1
#define XSYSMONPSV_PCSR_STATUS_INCAL_MASK    0X00000008

#define XSYSMONPSV_PCSR_STATUS_SCAN_CLEAR_PASS_SHIFT   2
#define XSYSMONPSV_PCSR_STATUS_SCAN_CLEAR_PASS_WIDTH   1
#define XSYSMONPSV_PCSR_STATUS_SCAN_CLEAR_PASS_MASK    0X00000004

#define XSYSMONPSV_PCSR_STATUS_SCAN_CLEAR_DONE_SHIFT   1
#define XSYSMONPSV_PCSR_STATUS_SCAN_CLEAR_DONE_WIDTH   1
#define XSYSMONPSV_PCSR_STATUS_SCAN_CLEAR_DONE_MASK    0X00000002

#define XSYSMONPSV_PCSR_STATUS_PCSRLOCK_SHIFT   0
#define XSYSMONPSV_PCSR_STATUS_PCSRLOCK_WIDTH   1
#define XSYSMONPSV_PCSR_STATUS_PCSRLOCK_MASK    0X00000001

/**
 * Register: XSYSMONPSV_PCSR_LOCK
 */
#define XSYSMONPSV_PCSR_LOCK     0X0000000C

#define XSYSMONPSV_PCSR_LOCK_STATE_SHIFT   0
#define XSYSMONPSV_PCSR_LOCK_STATE_WIDTH   1
#define XSYSMONPSV_PCSR_LOCK_STATE_MASK    0X00000001

/**
 * Register: XSYSMONPSV_ITR
 */
#define XSYSMONPSV_ITR     0X00000040

#define XSYSMONPSV_ITR_SSC_OVERFLOW_SHIFT   31
#define XSYSMONPSV_ITR_SSC_OVERFLOW_WIDTH   1
#define XSYSMONPSV_ITR_SSC_OVERFLOW_MASK    0X80000000

#define XSYSMONPSV_ITR_AXI_TIMEOUT_SHIFT   30
#define XSYSMONPSV_ITR_AXI_TIMEOUT_WIDTH   1
#define XSYSMONPSV_ITR_AXI_TIMEOUT_MASK    0X40000000

#define XSYSMONPSV_ITR_EXT_REF_DOWN_SHIFT   29
#define XSYSMONPSV_ITR_EXT_REF_DOWN_WIDTH   1
#define XSYSMONPSV_ITR_EXT_REF_DOWN_MASK    0X20000000

#define XSYSMONPSV_ITR_GOQ_DONE_SHIFT   28
#define XSYSMONPSV_ITR_GOQ_DONE_WIDTH   1
#define XSYSMONPSV_ITR_GOQ_DONE_MASK    0X10000000

#define XSYSMONPSV_ITR_AXI_ERROR_RESPONSE_SHIFT   27
#define XSYSMONPSV_ITR_AXI_ERROR_RESPONSE_WIDTH   1
#define XSYSMONPSV_ITR_AXI_ERROR_RESPONSE_MASK    0X08000000

#define XSYSMONPSV_ITR_AXI_BUFF_OVERFLOW_SHIFT   26
#define XSYSMONPSV_ITR_AXI_BUFF_OVERFLOW_WIDTH   1
#define XSYSMONPSV_ITR_AXI_BUFF_OVERFLOW_MASK    0X04000000

#define XSYSMONPSV_ITR_SSC_VREF_CORRUPT4_SHIFT   25
#define XSYSMONPSV_ITR_SSC_VREF_CORRUPT4_WIDTH   1
#define XSYSMONPSV_ITR_SSC_VREF_CORRUPT4_MASK    0X02000000

#define XSYSMONPSV_ITR_SSC_VREF_CORRUPT3_SHIFT   24
#define XSYSMONPSV_ITR_SSC_VREF_CORRUPT3_WIDTH   1
#define XSYSMONPSV_ITR_SSC_VREF_CORRUPT3_MASK    0X01000000

#define XSYSMONPSV_ITR_SSC_VREF_CORRUPT2_SHIFT   23
#define XSYSMONPSV_ITR_SSC_VREF_CORRUPT2_WIDTH   1
#define XSYSMONPSV_ITR_SSC_VREF_CORRUPT2_MASK    0X00800000

#define XSYSMONPSV_ITR_SSC_VREF_CORRUPT1_SHIFT   22
#define XSYSMONPSV_ITR_SSC_VREF_CORRUPT1_WIDTH   1
#define XSYSMONPSV_ITR_SSC_VREF_CORRUPT1_MASK    0X00400000

#define XSYSMONPSV_ITR_SSC_VREF_CORRUPT0_SHIFT   21
#define XSYSMONPSV_ITR_SSC_VREF_CORRUPT0_WIDTH   1
#define XSYSMONPSV_ITR_SSC_VREF_CORRUPT0_MASK    0X00200000

#define XSYSMONPSV_ITR_SSC_MRKR_CORRUPT4_SHIFT   20
#define XSYSMONPSV_ITR_SSC_MRKR_CORRUPT4_WIDTH   1
#define XSYSMONPSV_ITR_SSC_MRKR_CORRUPT4_MASK    0X00100000

#define XSYSMONPSV_ITR_SSC_MRKR_CORRUPT3_SHIFT   19
#define XSYSMONPSV_ITR_SSC_MRKR_CORRUPT3_WIDTH   1
#define XSYSMONPSV_ITR_SSC_MRKR_CORRUPT3_MASK    0X00080000

#define XSYSMONPSV_ITR_SSC_MRKR_CORRUPT2_SHIFT   18
#define XSYSMONPSV_ITR_SSC_MRKR_CORRUPT2_WIDTH   1
#define XSYSMONPSV_ITR_SSC_MRKR_CORRUPT2_MASK    0X00040000

#define XSYSMONPSV_ITR_SSC_MRKR_CORRUPT1_SHIFT   17
#define XSYSMONPSV_ITR_SSC_MRKR_CORRUPT1_WIDTH   1
#define XSYSMONPSV_ITR_SSC_MRKR_CORRUPT1_MASK    0X00020000

#define XSYSMONPSV_ITR_SSC_MRKR_CORRUPT0_SHIFT   16
#define XSYSMONPSV_ITR_SSC_MRKR_CORRUPT0_WIDTH   1
#define XSYSMONPSV_ITR_SSC_MRKR_CORRUPT0_MASK    0X00010000

#define XSYSMONPSV_ITR_NEW_DATA3_SHIFT   15
#define XSYSMONPSV_ITR_NEW_DATA3_WIDTH   1
#define XSYSMONPSV_ITR_NEW_DATA3_MASK    0X00008000

#define XSYSMONPSV_ITR_NEW_DATA2_SHIFT   14
#define XSYSMONPSV_ITR_NEW_DATA2_WIDTH   1
#define XSYSMONPSV_ITR_NEW_DATA2_MASK    0X00004000

#define XSYSMONPSV_ITR_NEW_DATA1_SHIFT   13
#define XSYSMONPSV_ITR_NEW_DATA1_WIDTH   1
#define XSYSMONPSV_ITR_NEW_DATA1_MASK    0X00002000

#define XSYSMONPSV_ITR_NEW_DATA0_SHIFT   12
#define XSYSMONPSV_ITR_NEW_DATA0_WIDTH   1
#define XSYSMONPSV_ITR_NEW_DATA0_MASK    0X00001000

#define XSYSMONPSV_ITR_SECURE_EFUSE_DONE_SHIFT   11
#define XSYSMONPSV_ITR_SECURE_EFUSE_DONE_WIDTH   1
#define XSYSMONPSV_ITR_SECURE_EFUSE_DONE_MASK    0X00000800

#define XSYSMONPSV_ITR_SECURE_EFUSE_ERROR_SHIFT   10
#define XSYSMONPSV_ITR_SECURE_EFUSE_ERROR_WIDTH   1
#define XSYSMONPSV_ITR_SECURE_EFUSE_ERROR_MASK    0X00000400

#define XSYSMONPSV_ITR_TEMP_SHIFT   9
#define XSYSMONPSV_ITR_TEMP_WIDTH   1
#define XSYSMONPSV_ITR_TEMP_MASK    0X00000200

#define XSYSMONPSV_ITR_OT_SHIFT   8
#define XSYSMONPSV_ITR_OT_WIDTH   1
#define XSYSMONPSV_ITR_OT_MASK    0X00000100

#define XSYSMONPSV_ITR_ALARM7_SHIFT   7
#define XSYSMONPSV_ITR_ALARM7_WIDTH   1
#define XSYSMONPSV_ITR_ALARM7_MASK    0X00000080

#define XSYSMONPSV_ITR_ALARM6_SHIFT   6
#define XSYSMONPSV_ITR_ALARM6_WIDTH   1
#define XSYSMONPSV_ITR_ALARM6_MASK    0X00000040

#define XSYSMONPSV_ITR_ALARM5_SHIFT   5
#define XSYSMONPSV_ITR_ALARM5_WIDTH   1
#define XSYSMONPSV_ITR_ALARM5_MASK    0X00000020

#define XSYSMONPSV_ITR_ALARM4_SHIFT   4
#define XSYSMONPSV_ITR_ALARM4_WIDTH   1
#define XSYSMONPSV_ITR_ALARM4_MASK    0X00000010

#define XSYSMONPSV_ITR_ALARM3_SHIFT   3
#define XSYSMONPSV_ITR_ALARM3_WIDTH   1
#define XSYSMONPSV_ITR_ALARM3_MASK    0X00000008

#define XSYSMONPSV_ITR_ALARM2_SHIFT   2
#define XSYSMONPSV_ITR_ALARM2_WIDTH   1
#define XSYSMONPSV_ITR_ALARM2_MASK    0X00000004

#define XSYSMONPSV_ITR_ALARM1_SHIFT   1
#define XSYSMONPSV_ITR_ALARM1_WIDTH   1
#define XSYSMONPSV_ITR_ALARM1_MASK    0X00000002

#define XSYSMONPSV_ITR_ALARM0_SHIFT   0
#define XSYSMONPSV_ITR_ALARM0_WIDTH   1
#define XSYSMONPSV_ITR_ALARM0_MASK    0X00000001

/**
 * Register: XSYSMONPSV_ISR
 */
#define XSYSMONPSV_ISR_OFFSET     0X00000044

#define XSYSMONPSV_ISR_SSC_OVERFLOW_SHIFT   31
#define XSYSMONPSV_ISR_SSC_OVERFLOW_WIDTH   1
#define XSYSMONPSV_ISR_SSC_OVERFLOW_MASK    0X80000000

#define XSYSMONPSV_ISR_AXI_TIMEOUT_SHIFT   30
#define XSYSMONPSV_ISR_AXI_TIMEOUT_WIDTH   1
#define XSYSMONPSV_ISR_AXI_TIMEOUT_MASK    0X40000000

#define XSYSMONPSV_ISR_EXT_REF_DOWN_SHIFT   29
#define XSYSMONPSV_ISR_EXT_REF_DOWN_WIDTH   1
#define XSYSMONPSV_ISR_EXT_REF_DOWN_MASK    0X20000000

#define XSYSMONPSV_ISR_GOQ_DONE_SHIFT   28
#define XSYSMONPSV_ISR_GOQ_DONE_WIDTH   1
#define XSYSMONPSV_ISR_GOQ_DONE_MASK    0X10000000

#define XSYSMONPSV_ISR_AXI_ERROR_RESPONSE_SHIFT   27
#define XSYSMONPSV_ISR_AXI_ERROR_RESPONSE_WIDTH   1
#define XSYSMONPSV_ISR_AXI_ERROR_RESPONSE_MASK    0X08000000

#define XSYSMONPSV_ISR_AXI_BUFF_OVERFLOW_SHIFT   26
#define XSYSMONPSV_ISR_AXI_BUFF_OVERFLOW_WIDTH   1
#define XSYSMONPSV_ISR_AXI_BUFF_OVERFLOW_MASK    0X04000000

#define XSYSMONPSV_ISR_SSC_VREF_CORRUPT4_SHIFT   25
#define XSYSMONPSV_ISR_SSC_VREF_CORRUPT4_WIDTH   1
#define XSYSMONPSV_ISR_SSC_VREF_CORRUPT4_MASK    0X02000000

#define XSYSMONPSV_ISR_SSC_VREF_CORRUPT3_SHIFT   24
#define XSYSMONPSV_ISR_SSC_VREF_CORRUPT3_WIDTH   1
#define XSYSMONPSV_ISR_SSC_VREF_CORRUPT3_MASK    0X01000000

#define XSYSMONPSV_ISR_SSC_VREF_CORRUPT2_SHIFT   23
#define XSYSMONPSV_ISR_SSC_VREF_CORRUPT2_WIDTH   1
#define XSYSMONPSV_ISR_SSC_VREF_CORRUPT2_MASK    0X00800000

#define XSYSMONPSV_ISR_SSC_VREF_CORRUPT1_SHIFT   22
#define XSYSMONPSV_ISR_SSC_VREF_CORRUPT1_WIDTH   1
#define XSYSMONPSV_ISR_SSC_VREF_CORRUPT1_MASK    0X00400000

#define XSYSMONPSV_ISR_SSC_VREF_CORRUPT0_SHIFT   21
#define XSYSMONPSV_ISR_SSC_VREF_CORRUPT0_WIDTH   1
#define XSYSMONPSV_ISR_SSC_VREF_CORRUPT0_MASK    0X00200000

#define XSYSMONPSV_ISR_SSC_MRKR_CORRUPT4_SHIFT   20
#define XSYSMONPSV_ISR_SSC_MRKR_CORRUPT4_WIDTH   1
#define XSYSMONPSV_ISR_SSC_MRKR_CORRUPT4_MASK    0X00100000

#define XSYSMONPSV_ISR_SSC_MRKR_CORRUPT3_SHIFT   19
#define XSYSMONPSV_ISR_SSC_MRKR_CORRUPT3_WIDTH   1
#define XSYSMONPSV_ISR_SSC_MRKR_CORRUPT3_MASK    0X00080000

#define XSYSMONPSV_ISR_SSC_MRKR_CORRUPT2_SHIFT   18
#define XSYSMONPSV_ISR_SSC_MRKR_CORRUPT2_WIDTH   1
#define XSYSMONPSV_ISR_SSC_MRKR_CORRUPT2_MASK    0X00040000

#define XSYSMONPSV_ISR_SSC_MRKR_CORRUPT1_SHIFT   17
#define XSYSMONPSV_ISR_SSC_MRKR_CORRUPT1_WIDTH   1
#define XSYSMONPSV_ISR_SSC_MRKR_CORRUPT1_MASK    0X00020000

#define XSYSMONPSV_ISR_SSC_MRKR_CORRUPT0_SHIFT   16
#define XSYSMONPSV_ISR_SSC_MRKR_CORRUPT0_WIDTH   1
#define XSYSMONPSV_ISR_SSC_MRKR_CORRUPT0_MASK    0X00010000

#define XSYSMONPSV_ISR_NEW_DATA3_SHIFT   15
#define XSYSMONPSV_ISR_NEW_DATA3_WIDTH   1
#define XSYSMONPSV_ISR_NEW_DATA3_MASK    0X00008000

#define XSYSMONPSV_ISR_NEW_DATA2_SHIFT   14
#define XSYSMONPSV_ISR_NEW_DATA2_WIDTH   1
#define XSYSMONPSV_ISR_NEW_DATA2_MASK    0X00004000

#define XSYSMONPSV_ISR_NEW_DATA1_SHIFT   13
#define XSYSMONPSV_ISR_NEW_DATA1_WIDTH   1
#define XSYSMONPSV_ISR_NEW_DATA1_MASK    0X00002000

#define XSYSMONPSV_ISR_NEW_DATA0_SHIFT   12
#define XSYSMONPSV_ISR_NEW_DATA0_WIDTH   1
#define XSYSMONPSV_ISR_NEW_DATA0_MASK    0X00001000

#define XSYSMONPSV_ISR_SECURE_EFUSE_DONE_SHIFT   11
#define XSYSMONPSV_ISR_SECURE_EFUSE_DONE_WIDTH   1
#define XSYSMONPSV_ISR_SECURE_EFUSE_DONE_MASK    0X00000800

#define XSYSMONPSV_ISR_SECURE_EFUSE_ERROR_SHIFT   10
#define XSYSMONPSV_ISR_SECURE_EFUSE_ERROR_WIDTH   1
#define XSYSMONPSV_ISR_SECURE_EFUSE_ERROR_MASK    0X00000400

#define XSYSMONPSV_ISR_TEMP_SHIFT   9
#define XSYSMONPSV_ISR_TEMP_WIDTH   1
#define XSYSMONPSV_ISR_TEMP_MASK    0X00000200

#define XSYSMONPSV_ISR_OT_SHIFT   8
#define XSYSMONPSV_ISR_OT_WIDTH   1
#define XSYSMONPSV_ISR_OT_MASK    0X00000100

#define XSYSMONPSV_ISR_ALARM7_SHIFT   7
#define XSYSMONPSV_ISR_ALARM7_WIDTH   1
#define XSYSMONPSV_ISR_ALARM7_MASK    0X00000080

#define XSYSMONPSV_ISR_ALARM6_SHIFT   6
#define XSYSMONPSV_ISR_ALARM6_WIDTH   1
#define XSYSMONPSV_ISR_ALARM6_MASK    0X00000040

#define XSYSMONPSV_ISR_ALARM5_SHIFT   5
#define XSYSMONPSV_ISR_ALARM5_WIDTH   1
#define XSYSMONPSV_ISR_ALARM5_MASK    0X00000020

#define XSYSMONPSV_ISR_ALARM4_SHIFT   4
#define XSYSMONPSV_ISR_ALARM4_WIDTH   1
#define XSYSMONPSV_ISR_ALARM4_MASK    0X00000010

#define XSYSMONPSV_ISR_ALARM3_SHIFT   3
#define XSYSMONPSV_ISR_ALARM3_WIDTH   1
#define XSYSMONPSV_ISR_ALARM3_MASK    0X00000008

#define XSYSMONPSV_ISR_ALARM2_SHIFT   2
#define XSYSMONPSV_ISR_ALARM2_WIDTH   1
#define XSYSMONPSV_ISR_ALARM2_MASK    0X00000004

#define XSYSMONPSV_ISR_ALARM1_SHIFT   1
#define XSYSMONPSV_ISR_ALARM1_WIDTH   1
#define XSYSMONPSV_ISR_ALARM1_MASK    0X00000002

#define XSYSMONPSV_ISR_ALARM0_SHIFT   0
#define XSYSMONPSV_ISR_ALARM0_WIDTH   1
#define XSYSMONPSV_ISR_ALARM0_MASK    0X00000001

/**
 * Register: XSYSMONPSV_IMR0
 */
#define XSYSMONPSV_IMR0_OFFSET     0X00000048

#define XSYSMONPSV_IMR0_SSC_OVERFLOW_SHIFT   31
#define XSYSMONPSV_IMR0_SSC_OVERFLOW_WIDTH   1
#define XSYSMONPSV_IMR0_SSC_OVERFLOW_MASK    0X80000000

#define XSYSMONPSV_IMR0_AXI_TIMEOUT_SHIFT   30
#define XSYSMONPSV_IMR0_AXI_TIMEOUT_WIDTH   1
#define XSYSMONPSV_IMR0_AXI_TIMEOUT_MASK    0X40000000

#define XSYSMONPSV_IMR0_EXT_REF_DOWN_SHIFT   29
#define XSYSMONPSV_IMR0_EXT_REF_DOWN_WIDTH   1
#define XSYSMONPSV_IMR0_EXT_REF_DOWN_MASK    0X20000000

#define XSYSMONPSV_IMR0_GOQ_DONE_SHIFT   28
#define XSYSMONPSV_IMR0_GOQ_DONE_WIDTH   1
#define XSYSMONPSV_IMR0_GOQ_DONE_MASK    0X10000000

#define XSYSMONPSV_IMR0_AXI_ERROR_RESPONSE_SHIFT   27
#define XSYSMONPSV_IMR0_AXI_ERROR_RESPONSE_WIDTH   1
#define XSYSMONPSV_IMR0_AXI_ERROR_RESPONSE_MASK    0X08000000

#define XSYSMONPSV_IMR0_AXI_BUFF_OVERFLOW_SHIFT   26
#define XSYSMONPSV_IMR0_AXI_BUFF_OVERFLOW_WIDTH   1
#define XSYSMONPSV_IMR0_AXI_BUFF_OVERFLOW_MASK    0X04000000

#define XSYSMONPSV_IMR0_SSC_VREF_CORRUPT4_SHIFT   25
#define XSYSMONPSV_IMR0_SSC_VREF_CORRUPT4_WIDTH   1
#define XSYSMONPSV_IMR0_SSC_VREF_CORRUPT4_MASK    0X02000000

#define XSYSMONPSV_IMR0_SSC_VREF_CORRUPT3_SHIFT   24
#define XSYSMONPSV_IMR0_SSC_VREF_CORRUPT3_WIDTH   1
#define XSYSMONPSV_IMR0_SSC_VREF_CORRUPT3_MASK    0X01000000

#define XSYSMONPSV_IMR0_SSC_VREF_CORRUPT2_SHIFT   23
#define XSYSMONPSV_IMR0_SSC_VREF_CORRUPT2_WIDTH   1
#define XSYSMONPSV_IMR0_SSC_VREF_CORRUPT2_MASK    0X00800000

#define XSYSMONPSV_IMR0_SSC_VREF_CORRUPT1_SHIFT   22
#define XSYSMONPSV_IMR0_SSC_VREF_CORRUPT1_WIDTH   1
#define XSYSMONPSV_IMR0_SSC_VREF_CORRUPT1_MASK    0X00400000

#define XSYSMONPSV_IMR0_SSC_VREF_CORRUPT0_SHIFT   21
#define XSYSMONPSV_IMR0_SSC_VREF_CORRUPT0_WIDTH   1
#define XSYSMONPSV_IMR0_SSC_VREF_CORRUPT0_MASK    0X00200000

#define XSYSMONPSV_IMR0_SSC_MRKR_CORRUPT4_SHIFT   20
#define XSYSMONPSV_IMR0_SSC_MRKR_CORRUPT4_WIDTH   1
#define XSYSMONPSV_IMR0_SSC_MRKR_CORRUPT4_MASK    0X00100000

#define XSYSMONPSV_IMR0_SSC_MRKR_CORRUPT3_SHIFT   19
#define XSYSMONPSV_IMR0_SSC_MRKR_CORRUPT3_WIDTH   1
#define XSYSMONPSV_IMR0_SSC_MRKR_CORRUPT3_MASK    0X00080000

#define XSYSMONPSV_IMR0_SSC_MRKR_CORRUPT2_SHIFT   18
#define XSYSMONPSV_IMR0_SSC_MRKR_CORRUPT2_WIDTH   1
#define XSYSMONPSV_IMR0_SSC_MRKR_CORRUPT2_MASK    0X00040000

#define XSYSMONPSV_IMR0_SSC_MRKR_CORRUPT1_SHIFT   17
#define XSYSMONPSV_IMR0_SSC_MRKR_CORRUPT1_WIDTH   1
#define XSYSMONPSV_IMR0_SSC_MRKR_CORRUPT1_MASK    0X00020000

#define XSYSMONPSV_IMR0_SSC_MRKR_CORRUPT0_SHIFT   16
#define XSYSMONPSV_IMR0_SSC_MRKR_CORRUPT0_WIDTH   1
#define XSYSMONPSV_IMR0_SSC_MRKR_CORRUPT0_MASK    0X00010000

#define XSYSMONPSV_IMR0_NEW_DATA3_SHIFT   15
#define XSYSMONPSV_IMR0_NEW_DATA3_WIDTH   1
#define XSYSMONPSV_IMR0_NEW_DATA3_MASK    0X00008000

#define XSYSMONPSV_IMR0_NEW_DATA2_SHIFT   14
#define XSYSMONPSV_IMR0_NEW_DATA2_WIDTH   1
#define XSYSMONPSV_IMR0_NEW_DATA2_MASK    0X00004000

#define XSYSMONPSV_IMR0_NEW_DATA1_SHIFT   13
#define XSYSMONPSV_IMR0_NEW_DATA1_WIDTH   1
#define XSYSMONPSV_IMR0_NEW_DATA1_MASK    0X00002000

#define XSYSMONPSV_IMR0_NEW_DATA0_SHIFT   12
#define XSYSMONPSV_IMR0_NEW_DATA0_WIDTH   1
#define XSYSMONPSV_IMR0_NEW_DATA0_MASK    0X00001000

#define XSYSMONPSV_IMR0_SECURE_EFUSE_DONE_SHIFT   11
#define XSYSMONPSV_IMR0_SECURE_EFUSE_DONE_WIDTH   1
#define XSYSMONPSV_IMR0_SECURE_EFUSE_DONE_MASK    0X00000800

#define XSYSMONPSV_IMR0_SECURE_EFUSE_ERROR_SHIFT   10
#define XSYSMONPSV_IMR0_SECURE_EFUSE_ERROR_WIDTH   1
#define XSYSMONPSV_IMR0_SECURE_EFUSE_ERROR_MASK    0X00000400

#define XSYSMONPSV_IMR0_TEMP_SHIFT   9
#define XSYSMONPSV_IMR0_TEMP_WIDTH   1
#define XSYSMONPSV_IMR0_TEMP_MASK    0X00000200

#define XSYSMONPSV_IMR0_OT_SHIFT   8
#define XSYSMONPSV_IMR0_OT_WIDTH   1
#define XSYSMONPSV_IMR0_OT_MASK    0X00000100

#define XSYSMONPSV_IMR0_ALARM7_SHIFT   7
#define XSYSMONPSV_IMR0_ALARM7_WIDTH   1
#define XSYSMONPSV_IMR0_ALARM7_MASK    0X00000080

#define XSYSMONPSV_IMR0_ALARM6_SHIFT   6
#define XSYSMONPSV_IMR0_ALARM6_WIDTH   1
#define XSYSMONPSV_IMR0_ALARM6_MASK    0X00000040

#define XSYSMONPSV_IMR0_ALARM5_SHIFT   5
#define XSYSMONPSV_IMR0_ALARM5_WIDTH   1
#define XSYSMONPSV_IMR0_ALARM5_MASK    0X00000020

#define XSYSMONPSV_IMR0_ALARM4_SHIFT   4
#define XSYSMONPSV_IMR0_ALARM4_WIDTH   1
#define XSYSMONPSV_IMR0_ALARM4_MASK    0X00000010

#define XSYSMONPSV_IMR0_ALARM3_SHIFT   3
#define XSYSMONPSV_IMR0_ALARM3_WIDTH   1
#define XSYSMONPSV_IMR0_ALARM3_MASK    0X00000008

#define XSYSMONPSV_IMR0_ALARM2_SHIFT   2
#define XSYSMONPSV_IMR0_ALARM2_WIDTH   1
#define XSYSMONPSV_IMR0_ALARM2_MASK    0X00000004

#define XSYSMONPSV_IMR0_ALARM1_SHIFT   1
#define XSYSMONPSV_IMR0_ALARM1_WIDTH   1
#define XSYSMONPSV_IMR0_ALARM1_MASK    0X00000002

#define XSYSMONPSV_IMR0_ALARM0_SHIFT   0
#define XSYSMONPSV_IMR0_ALARM0_WIDTH   1
#define XSYSMONPSV_IMR0_ALARM0_MASK    0X00000001

/**
 * Register: XSYSMONPSV_IER0
 */
#define XSYSMONPSV_IER0_OFFSET     0X0000004C
#define XSYSMONPSV_IXR0_MASK	   0xFFFFFFFF

#define XSYSMONPSV_IER0_SSC_OVERFLOW_SHIFT   31
#define XSYSMONPSV_IER0_SSC_OVERFLOW_WIDTH   1
#define XSYSMONPSV_IER0_SSC_OVERFLOW_MASK    0X80000000

#define XSYSMONPSV_IER0_AXI_TIMEOUT_SHIFT   30
#define XSYSMONPSV_IER0_AXI_TIMEOUT_WIDTH   1
#define XSYSMONPSV_IER0_AXI_TIMEOUT_MASK    0X40000000

#define XSYSMONPSV_IER0_EXT_REF_DOWN_SHIFT   29
#define XSYSMONPSV_IER0_EXT_REF_DOWN_WIDTH   1
#define XSYSMONPSV_IER0_EXT_REF_DOWN_MASK    0X20000000

#define XSYSMONPSV_IER0_GOQ_DONE_SHIFT   28
#define XSYSMONPSV_IER0_GOQ_DONE_WIDTH   1
#define XSYSMONPSV_IER0_GOQ_DONE_MASK    0X10000000

#define XSYSMONPSV_IER0_AXI_ERROR_RESPONSE_SHIFT   27
#define XSYSMONPSV_IER0_AXI_ERROR_RESPONSE_WIDTH   1
#define XSYSMONPSV_IER0_AXI_ERROR_RESPONSE_MASK    0X08000000

#define XSYSMONPSV_IER0_AXI_BUFF_OVERFLOW_SHIFT   26
#define XSYSMONPSV_IER0_AXI_BUFF_OVERFLOW_WIDTH   1
#define XSYSMONPSV_IER0_AXI_BUFF_OVERFLOW_MASK    0X04000000

#define XSYSMONPSV_IER0_SSC_VREF_CORRUPT4_SHIFT   25
#define XSYSMONPSV_IER0_SSC_VREF_CORRUPT4_WIDTH   1
#define XSYSMONPSV_IER0_SSC_VREF_CORRUPT4_MASK    0X02000000

#define XSYSMONPSV_IER0_SSC_VREF_CORRUPT3_SHIFT   24
#define XSYSMONPSV_IER0_SSC_VREF_CORRUPT3_WIDTH   1
#define XSYSMONPSV_IER0_SSC_VREF_CORRUPT3_MASK    0X01000000

#define XSYSMONPSV_IER0_SSC_VREF_CORRUPT2_SHIFT   23
#define XSYSMONPSV_IER0_SSC_VREF_CORRUPT2_WIDTH   1
#define XSYSMONPSV_IER0_SSC_VREF_CORRUPT2_MASK    0X00800000

#define XSYSMONPSV_IER0_SSC_VREF_CORRUPT1_SHIFT   22
#define XSYSMONPSV_IER0_SSC_VREF_CORRUPT1_WIDTH   1
#define XSYSMONPSV_IER0_SSC_VREF_CORRUPT1_MASK    0X00400000

#define XSYSMONPSV_IER0_SSC_VREF_CORRUPT0_SHIFT   21
#define XSYSMONPSV_IER0_SSC_VREF_CORRUPT0_WIDTH   1
#define XSYSMONPSV_IER0_SSC_VREF_CORRUPT0_MASK    0X00200000

#define XSYSMONPSV_IER0_SSC_MRKR_CORRUPT4_SHIFT   20
#define XSYSMONPSV_IER0_SSC_MRKR_CORRUPT4_WIDTH   1
#define XSYSMONPSV_IER0_SSC_MRKR_CORRUPT4_MASK    0X00100000

#define XSYSMONPSV_IER0_SSC_MRKR_CORRUPT3_SHIFT   19
#define XSYSMONPSV_IER0_SSC_MRKR_CORRUPT3_WIDTH   1
#define XSYSMONPSV_IER0_SSC_MRKR_CORRUPT3_MASK    0X00080000

#define XSYSMONPSV_IER0_SSC_MRKR_CORRUPT2_SHIFT   18
#define XSYSMONPSV_IER0_SSC_MRKR_CORRUPT2_WIDTH   1
#define XSYSMONPSV_IER0_SSC_MRKR_CORRUPT2_MASK    0X00040000

#define XSYSMONPSV_IER0_SSC_MRKR_CORRUPT1_SHIFT   17
#define XSYSMONPSV_IER0_SSC_MRKR_CORRUPT1_WIDTH   1
#define XSYSMONPSV_IER0_SSC_MRKR_CORRUPT1_MASK    0X00020000

#define XSYSMONPSV_IER0_SSC_MRKR_CORRUPT0_SHIFT   16
#define XSYSMONPSV_IER0_SSC_MRKR_CORRUPT0_WIDTH   1
#define XSYSMONPSV_IER0_SSC_MRKR_CORRUPT0_MASK    0X00010000

#define XSYSMONPSV_IER0_NEW_DATA3_SHIFT   15
#define XSYSMONPSV_IER0_NEW_DATA3_WIDTH   1
#define XSYSMONPSV_IER0_NEW_DATA3_MASK    0X00008000

#define XSYSMONPSV_IER0_NEW_DATA2_SHIFT   14
#define XSYSMONPSV_IER0_NEW_DATA2_WIDTH   1
#define XSYSMONPSV_IER0_NEW_DATA2_MASK    0X00004000

#define XSYSMONPSV_IER0_NEW_DATA1_SHIFT   13
#define XSYSMONPSV_IER0_NEW_DATA1_WIDTH   1
#define XSYSMONPSV_IER0_NEW_DATA1_MASK    0X00002000

#define XSYSMONPSV_IER0_NEW_DATA0_SHIFT   12
#define XSYSMONPSV_IER0_NEW_DATA0_WIDTH   1
#define XSYSMONPSV_IER0_NEW_DATA0_MASK    0X00001000

#define XSYSMONPSV_IER0_SECURE_EFUSE_DONE_SHIFT   11
#define XSYSMONPSV_IER0_SECURE_EFUSE_DONE_WIDTH   1
#define XSYSMONPSV_IER0_SECURE_EFUSE_DONE_MASK    0X00000800

#define XSYSMONPSV_IER0_SECURE_EFUSE_ERROR_SHIFT   10
#define XSYSMONPSV_IER0_SECURE_EFUSE_ERROR_WIDTH   1
#define XSYSMONPSV_IER0_SECURE_EFUSE_ERROR_MASK    0X00000400

#define XSYSMONPSV_IER0_TEMP_SHIFT   9
#define XSYSMONPSV_IER0_TEMP_WIDTH   1
#define XSYSMONPSV_IER0_TEMP_MASK    0X00000200

#define XSYSMONPSV_IER0_OT_SHIFT   8
#define XSYSMONPSV_IER0_OT_WIDTH   1
#define XSYSMONPSV_IER0_OT_MASK    0X00000100

#define XSYSMONPSV_IER0_ALARM7_SHIFT   7
#define XSYSMONPSV_IER0_ALARM7_WIDTH   1
#define XSYSMONPSV_IER0_ALARM7_MASK    0X00000080

#define XSYSMONPSV_IER0_ALARM6_SHIFT   6
#define XSYSMONPSV_IER0_ALARM6_WIDTH   1
#define XSYSMONPSV_IER0_ALARM6_MASK    0X00000040

#define XSYSMONPSV_IER0_ALARM5_SHIFT   5
#define XSYSMONPSV_IER0_ALARM5_WIDTH   1
#define XSYSMONPSV_IER0_ALARM5_MASK    0X00000020

#define XSYSMONPSV_IER0_ALARM4_SHIFT   4
#define XSYSMONPSV_IER0_ALARM4_WIDTH   1
#define XSYSMONPSV_IER0_ALARM4_MASK    0X00000010

#define XSYSMONPSV_IER0_ALARM3_SHIFT   3
#define XSYSMONPSV_IER0_ALARM3_WIDTH   1
#define XSYSMONPSV_IER0_ALARM3_MASK    0X00000008

#define XSYSMONPSV_IER0_ALARM2_SHIFT   2
#define XSYSMONPSV_IER0_ALARM2_WIDTH   1
#define XSYSMONPSV_IER0_ALARM2_MASK    0X00000004

#define XSYSMONPSV_IER0_ALARM1_SHIFT   1
#define XSYSMONPSV_IER0_ALARM1_WIDTH   1
#define XSYSMONPSV_IER0_ALARM1_MASK    0X00000002

#define XSYSMONPSV_IER0_ALARM0_SHIFT   0
#define XSYSMONPSV_IER0_ALARM0_WIDTH   1
#define XSYSMONPSV_IER0_ALARM0_MASK    0X00000001

/**
 * Register: XSYSMONPSV_IDR0
 */
#define XSYSMONPSV_IDR0_OFFSET     0X00000050

#define XSYSMONPSV_IDR0_SSC_OVERFLOW_SHIFT   31
#define XSYSMONPSV_IDR0_SSC_OVERFLOW_WIDTH   1
#define XSYSMONPSV_IDR0_SSC_OVERFLOW_MASK    0X80000000

#define XSYSMONPSV_IDR0_AXI_TIMEOUT_SHIFT   30
#define XSYSMONPSV_IDR0_AXI_TIMEOUT_WIDTH   1
#define XSYSMONPSV_IDR0_AXI_TIMEOUT_MASK    0X40000000

#define XSYSMONPSV_IDR0_EXT_REF_DOWN_SHIFT   29
#define XSYSMONPSV_IDR0_EXT_REF_DOWN_WIDTH   1
#define XSYSMONPSV_IDR0_EXT_REF_DOWN_MASK    0X20000000

#define XSYSMONPSV_IDR0_GOQ_DONE_SHIFT   28
#define XSYSMONPSV_IDR0_GOQ_DONE_WIDTH   1
#define XSYSMONPSV_IDR0_GOQ_DONE_MASK    0X10000000

#define XSYSMONPSV_IDR0_AXI_ERROR_RESPONSE_SHIFT   27
#define XSYSMONPSV_IDR0_AXI_ERROR_RESPONSE_WIDTH   1
#define XSYSMONPSV_IDR0_AXI_ERROR_RESPONSE_MASK    0X08000000

#define XSYSMONPSV_IDR0_AXI_BUFF_OVERFLOW_SHIFT   26
#define XSYSMONPSV_IDR0_AXI_BUFF_OVERFLOW_WIDTH   1
#define XSYSMONPSV_IDR0_AXI_BUFF_OVERFLOW_MASK    0X04000000

#define XSYSMONPSV_IDR0_SSC_VREF_CORRUPT4_SHIFT   25
#define XSYSMONPSV_IDR0_SSC_VREF_CORRUPT4_WIDTH   1
#define XSYSMONPSV_IDR0_SSC_VREF_CORRUPT4_MASK    0X02000000

#define XSYSMONPSV_IDR0_SSC_VREF_CORRUPT3_SHIFT   24
#define XSYSMONPSV_IDR0_SSC_VREF_CORRUPT3_WIDTH   1
#define XSYSMONPSV_IDR0_SSC_VREF_CORRUPT3_MASK    0X01000000

#define XSYSMONPSV_IDR0_SSC_VREF_CORRUPT2_SHIFT   23
#define XSYSMONPSV_IDR0_SSC_VREF_CORRUPT2_WIDTH   1
#define XSYSMONPSV_IDR0_SSC_VREF_CORRUPT2_MASK    0X00800000

#define XSYSMONPSV_IDR0_SSC_VREF_CORRUPT1_SHIFT   22
#define XSYSMONPSV_IDR0_SSC_VREF_CORRUPT1_WIDTH   1
#define XSYSMONPSV_IDR0_SSC_VREF_CORRUPT1_MASK    0X00400000

#define XSYSMONPSV_IDR0_SSC_VREF_CORRUPT0_SHIFT   21
#define XSYSMONPSV_IDR0_SSC_VREF_CORRUPT0_WIDTH   1
#define XSYSMONPSV_IDR0_SSC_VREF_CORRUPT0_MASK    0X00200000

#define XSYSMONPSV_IDR0_SSC_MRKR_CORRUPT4_SHIFT   20
#define XSYSMONPSV_IDR0_SSC_MRKR_CORRUPT4_WIDTH   1
#define XSYSMONPSV_IDR0_SSC_MRKR_CORRUPT4_MASK    0X00100000

#define XSYSMONPSV_IDR0_SSC_MRKR_CORRUPT3_SHIFT   19
#define XSYSMONPSV_IDR0_SSC_MRKR_CORRUPT3_WIDTH   1
#define XSYSMONPSV_IDR0_SSC_MRKR_CORRUPT3_MASK    0X00080000

#define XSYSMONPSV_IDR0_SSC_MRKR_CORRUPT2_SHIFT   18
#define XSYSMONPSV_IDR0_SSC_MRKR_CORRUPT2_WIDTH   1
#define XSYSMONPSV_IDR0_SSC_MRKR_CORRUPT2_MASK    0X00040000

#define XSYSMONPSV_IDR0_SSC_MRKR_CORRUPT1_SHIFT   17
#define XSYSMONPSV_IDR0_SSC_MRKR_CORRUPT1_WIDTH   1
#define XSYSMONPSV_IDR0_SSC_MRKR_CORRUPT1_MASK    0X00020000

#define XSYSMONPSV_IDR0_SSC_MRKR_CORRUPT0_SHIFT   16
#define XSYSMONPSV_IDR0_SSC_MRKR_CORRUPT0_WIDTH   1
#define XSYSMONPSV_IDR0_SSC_MRKR_CORRUPT0_MASK    0X00010000

#define XSYSMONPSV_IDR0_NEW_DATA3_SHIFT   15
#define XSYSMONPSV_IDR0_NEW_DATA3_WIDTH   1
#define XSYSMONPSV_IDR0_NEW_DATA3_MASK    0X00008000

#define XSYSMONPSV_IDR0_NEW_DATA2_SHIFT   14
#define XSYSMONPSV_IDR0_NEW_DATA2_WIDTH   1
#define XSYSMONPSV_IDR0_NEW_DATA2_MASK    0X00004000

#define XSYSMONPSV_IDR0_NEW_DATA1_SHIFT   13
#define XSYSMONPSV_IDR0_NEW_DATA1_WIDTH   1
#define XSYSMONPSV_IDR0_NEW_DATA1_MASK    0X00002000

#define XSYSMONPSV_IDR0_NEW_DATA0_SHIFT   12
#define XSYSMONPSV_IDR0_NEW_DATA0_WIDTH   1
#define XSYSMONPSV_IDR0_NEW_DATA0_MASK    0X00001000

#define XSYSMONPSV_IDR0_SECURE_EFUSE_DONE_SHIFT   11
#define XSYSMONPSV_IDR0_SECURE_EFUSE_DONE_WIDTH   1
#define XSYSMONPSV_IDR0_SECURE_EFUSE_DONE_MASK    0X00000800

#define XSYSMONPSV_IDR0_SECURE_EFUSE_ERROR_SHIFT   10
#define XSYSMONPSV_IDR0_SECURE_EFUSE_ERROR_WIDTH   1
#define XSYSMONPSV_IDR0_SECURE_EFUSE_ERROR_MASK    0X00000400

#define XSYSMONPSV_IDR0_TEMP_SHIFT   9
#define XSYSMONPSV_IDR0_TEMP_WIDTH   1
#define XSYSMONPSV_IDR0_TEMP_MASK    0X00000200

#define XSYSMONPSV_IDR0_OT_SHIFT   8
#define XSYSMONPSV_IDR0_OT_WIDTH   1
#define XSYSMONPSV_IDR0_OT_MASK    0X00000100

#define XSYSMONPSV_IDR0_ALARM7_SHIFT   7
#define XSYSMONPSV_IDR0_ALARM7_WIDTH   1
#define XSYSMONPSV_IDR0_ALARM7_MASK    0X00000080

#define XSYSMONPSV_IDR0_ALARM6_SHIFT   6
#define XSYSMONPSV_IDR0_ALARM6_WIDTH   1
#define XSYSMONPSV_IDR0_ALARM6_MASK    0X00000040

#define XSYSMONPSV_IDR0_ALARM5_SHIFT   5
#define XSYSMONPSV_IDR0_ALARM5_WIDTH   1
#define XSYSMONPSV_IDR0_ALARM5_MASK    0X00000020

#define XSYSMONPSV_IDR0_ALARM4_SHIFT   4
#define XSYSMONPSV_IDR0_ALARM4_WIDTH   1
#define XSYSMONPSV_IDR0_ALARM4_MASK    0X00000010

#define XSYSMONPSV_IDR0_ALARM3_SHIFT   3
#define XSYSMONPSV_IDR0_ALARM3_WIDTH   1
#define XSYSMONPSV_IDR0_ALARM3_MASK    0X00000008

#define XSYSMONPSV_IDR0_ALARM2_SHIFT   2
#define XSYSMONPSV_IDR0_ALARM2_WIDTH   1
#define XSYSMONPSV_IDR0_ALARM2_MASK    0X00000004

#define XSYSMONPSV_IDR0_ALARM1_SHIFT   1
#define XSYSMONPSV_IDR0_ALARM1_WIDTH   1
#define XSYSMONPSV_IDR0_ALARM1_MASK    0X00000002

#define XSYSMONPSV_IDR0_ALARM0_SHIFT   0
#define XSYSMONPSV_IDR0_ALARM0_WIDTH   1
#define XSYSMONPSV_IDR0_ALARM0_MASK    0X00000001

/**
 * Register: XSYSMONPSV_IMR1
 */
#define XSYSMONPSV_IMR1_OFFSET     0X00000054

#define XSYSMONPSV_IMR1_SSC_OVERFLOW_SHIFT   31
#define XSYSMONPSV_IMR1_SSC_OVERFLOW_WIDTH   1
#define XSYSMONPSV_IMR1_SSC_OVERFLOW_MASK    0X80000000

#define XSYSMONPSV_IMR1_AXI_TIMEOUT_SHIFT   30
#define XSYSMONPSV_IMR1_AXI_TIMEOUT_WIDTH   1
#define XSYSMONPSV_IMR1_AXI_TIMEOUT_MASK    0X40000000

#define XSYSMONPSV_IMR1_EXT_REF_DOWN_SHIFT   29
#define XSYSMONPSV_IMR1_EXT_REF_DOWN_WIDTH   1
#define XSYSMONPSV_IMR1_EXT_REF_DOWN_MASK    0X20000000

#define XSYSMONPSV_IMR1_GOQ_DONE_SHIFT   28
#define XSYSMONPSV_IMR1_GOQ_DONE_WIDTH   1
#define XSYSMONPSV_IMR1_GOQ_DONE_MASK    0X10000000

#define XSYSMONPSV_IMR1_AXI_ERROR_RESPONSE_SHIFT   27
#define XSYSMONPSV_IMR1_AXI_ERROR_RESPONSE_WIDTH   1
#define XSYSMONPSV_IMR1_AXI_ERROR_RESPONSE_MASK    0X08000000

#define XSYSMONPSV_IMR1_AXI_BUFF_OVERFLOW_SHIFT   26
#define XSYSMONPSV_IMR1_AXI_BUFF_OVERFLOW_WIDTH   1
#define XSYSMONPSV_IMR1_AXI_BUFF_OVERFLOW_MASK    0X04000000

#define XSYSMONPSV_IMR1_SSC_VREF_CORRUPT4_SHIFT   25
#define XSYSMONPSV_IMR1_SSC_VREF_CORRUPT4_WIDTH   1
#define XSYSMONPSV_IMR1_SSC_VREF_CORRUPT4_MASK    0X02000000

#define XSYSMONPSV_IMR1_SSC_VREF_CORRUPT3_SHIFT   24
#define XSYSMONPSV_IMR1_SSC_VREF_CORRUPT3_WIDTH   1
#define XSYSMONPSV_IMR1_SSC_VREF_CORRUPT3_MASK    0X01000000

#define XSYSMONPSV_IMR1_SSC_VREF_CORRUPT2_SHIFT   23
#define XSYSMONPSV_IMR1_SSC_VREF_CORRUPT2_WIDTH   1
#define XSYSMONPSV_IMR1_SSC_VREF_CORRUPT2_MASK    0X00800000

#define XSYSMONPSV_IMR1_SSC_VREF_CORRUPT1_SHIFT   22
#define XSYSMONPSV_IMR1_SSC_VREF_CORRUPT1_WIDTH   1
#define XSYSMONPSV_IMR1_SSC_VREF_CORRUPT1_MASK    0X00400000

#define XSYSMONPSV_IMR1_SSC_VREF_CORRUPT0_SHIFT   21
#define XSYSMONPSV_IMR1_SSC_VREF_CORRUPT0_WIDTH   1
#define XSYSMONPSV_IMR1_SSC_VREF_CORRUPT0_MASK    0X00200000

#define XSYSMONPSV_IMR1_SSC_MRKR_CORRUPT4_SHIFT   20
#define XSYSMONPSV_IMR1_SSC_MRKR_CORRUPT4_WIDTH   1
#define XSYSMONPSV_IMR1_SSC_MRKR_CORRUPT4_MASK    0X00100000

#define XSYSMONPSV_IMR1_SSC_MRKR_CORRUPT3_SHIFT   19
#define XSYSMONPSV_IMR1_SSC_MRKR_CORRUPT3_WIDTH   1
#define XSYSMONPSV_IMR1_SSC_MRKR_CORRUPT3_MASK    0X00080000

#define XSYSMONPSV_IMR1_SSC_MRKR_CORRUPT2_SHIFT   18
#define XSYSMONPSV_IMR1_SSC_MRKR_CORRUPT2_WIDTH   1
#define XSYSMONPSV_IMR1_SSC_MRKR_CORRUPT2_MASK    0X00040000

#define XSYSMONPSV_IMR1_SSC_MRKR_CORRUPT1_SHIFT   17
#define XSYSMONPSV_IMR1_SSC_MRKR_CORRUPT1_WIDTH   1
#define XSYSMONPSV_IMR1_SSC_MRKR_CORRUPT1_MASK    0X00020000

#define XSYSMONPSV_IMR1_SSC_MRKR_CORRUPT0_SHIFT   16
#define XSYSMONPSV_IMR1_SSC_MRKR_CORRUPT0_WIDTH   1
#define XSYSMONPSV_IMR1_SSC_MRKR_CORRUPT0_MASK    0X00010000

#define XSYSMONPSV_IMR1_NEW_DATA3_SHIFT   15
#define XSYSMONPSV_IMR1_NEW_DATA3_WIDTH   1
#define XSYSMONPSV_IMR1_NEW_DATA3_MASK    0X00008000

#define XSYSMONPSV_IMR1_NEW_DATA2_SHIFT   14
#define XSYSMONPSV_IMR1_NEW_DATA2_WIDTH   1
#define XSYSMONPSV_IMR1_NEW_DATA2_MASK    0X00004000

#define XSYSMONPSV_IMR1_NEW_DATA1_SHIFT   13
#define XSYSMONPSV_IMR1_NEW_DATA1_WIDTH   1
#define XSYSMONPSV_IMR1_NEW_DATA1_MASK    0X00002000

#define XSYSMONPSV_IMR1_NEW_DATA0_SHIFT   12
#define XSYSMONPSV_IMR1_NEW_DATA0_WIDTH   1
#define XSYSMONPSV_IMR1_NEW_DATA0_MASK    0X00001000

#define XSYSMONPSV_IMR1_SECURE_EFUSE_DONE_SHIFT   11
#define XSYSMONPSV_IMR1_SECURE_EFUSE_DONE_WIDTH   1
#define XSYSMONPSV_IMR1_SECURE_EFUSE_DONE_MASK    0X00000800

#define XSYSMONPSV_IMR1_SECURE_EFUSE_ERROR_SHIFT   10
#define XSYSMONPSV_IMR1_SECURE_EFUSE_ERROR_WIDTH   1
#define XSYSMONPSV_IMR1_SECURE_EFUSE_ERROR_MASK    0X00000400

#define XSYSMONPSV_IMR1_TEMP_SHIFT   9
#define XSYSMONPSV_IMR1_TEMP_WIDTH   1
#define XSYSMONPSV_IMR1_TEMP_MASK    0X00000200

#define XSYSMONPSV_IMR1_OT_SHIFT   8
#define XSYSMONPSV_IMR1_OT_WIDTH   1
#define XSYSMONPSV_IMR1_OT_MASK    0X00000100

#define XSYSMONPSV_IMR1_ALARM7_SHIFT   7
#define XSYSMONPSV_IMR1_ALARM7_WIDTH   1
#define XSYSMONPSV_IMR1_ALARM7_MASK    0X00000080

#define XSYSMONPSV_IMR1_ALARM6_SHIFT   6
#define XSYSMONPSV_IMR1_ALARM6_WIDTH   1
#define XSYSMONPSV_IMR1_ALARM6_MASK    0X00000040

#define XSYSMONPSV_IMR1_ALARM5_SHIFT   5
#define XSYSMONPSV_IMR1_ALARM5_WIDTH   1
#define XSYSMONPSV_IMR1_ALARM5_MASK    0X00000020

#define XSYSMONPSV_IMR1_ALARM4_SHIFT   4
#define XSYSMONPSV_IMR1_ALARM4_WIDTH   1
#define XSYSMONPSV_IMR1_ALARM4_MASK    0X00000010

#define XSYSMONPSV_IMR1_ALARM3_SHIFT   3
#define XSYSMONPSV_IMR1_ALARM3_WIDTH   1
#define XSYSMONPSV_IMR1_ALARM3_MASK    0X00000008

#define XSYSMONPSV_IMR1_ALARM2_SHIFT   2
#define XSYSMONPSV_IMR1_ALARM2_WIDTH   1
#define XSYSMONPSV_IMR1_ALARM2_MASK    0X00000004

#define XSYSMONPSV_IMR1_ALARM1_SHIFT   1
#define XSYSMONPSV_IMR1_ALARM1_WIDTH   1
#define XSYSMONPSV_IMR1_ALARM1_MASK    0X00000002

#define XSYSMONPSV_IMR1_ALARM0_SHIFT   0
#define XSYSMONPSV_IMR1_ALARM0_WIDTH   1
#define XSYSMONPSV_IMR1_ALARM0_MASK    0X00000001

/**
 * Register: XSYSMONPSV_IER1
 */
#define XSYSMONPSV_IER1_OFFSET     0X00000058
#define XSYSMONPSV_IXR1_SHIFT	   32
#define XSYSMONPSV_IXR1_MASK	   0xFFFFFFFF

#define XSYSMONPSV_IER1_SSC_OVERFLOW_SHIFT   31
#define XSYSMONPSV_IER1_SSC_OVERFLOW_WIDTH   1
#define XSYSMONPSV_IER1_SSC_OVERFLOW_MASK    0X80000000

#define XSYSMONPSV_IER1_AXI_TIMEOUT_SHIFT   30
#define XSYSMONPSV_IER1_AXI_TIMEOUT_WIDTH   1
#define XSYSMONPSV_IER1_AXI_TIMEOUT_MASK    0X40000000

#define XSYSMONPSV_IER1_EXT_REF_DOWN_SHIFT   29
#define XSYSMONPSV_IER1_EXT_REF_DOWN_WIDTH   1
#define XSYSMONPSV_IER1_EXT_REF_DOWN_MASK    0X20000000

#define XSYSMONPSV_IER1_GOQ_DONE_SHIFT   28
#define XSYSMONPSV_IER1_GOQ_DONE_WIDTH   1
#define XSYSMONPSV_IER1_GOQ_DONE_MASK    0X10000000

#define XSYSMONPSV_IER1_AXI_ERROR_RESPONSE_SHIFT   27
#define XSYSMONPSV_IER1_AXI_ERROR_RESPONSE_WIDTH   1
#define XSYSMONPSV_IER1_AXI_ERROR_RESPONSE_MASK    0X08000000

#define XSYSMONPSV_IER1_AXI_BUFF_OVERFLOW_SHIFT   26
#define XSYSMONPSV_IER1_AXI_BUFF_OVERFLOW_WIDTH   1
#define XSYSMONPSV_IER1_AXI_BUFF_OVERFLOW_MASK    0X04000000

#define XSYSMONPSV_IER1_SSC_VREF_CORRUPT4_SHIFT   25
#define XSYSMONPSV_IER1_SSC_VREF_CORRUPT4_WIDTH   1
#define XSYSMONPSV_IER1_SSC_VREF_CORRUPT4_MASK    0X02000000

#define XSYSMONPSV_IER1_SSC_VREF_CORRUPT3_SHIFT   24
#define XSYSMONPSV_IER1_SSC_VREF_CORRUPT3_WIDTH   1
#define XSYSMONPSV_IER1_SSC_VREF_CORRUPT3_MASK    0X01000000

#define XSYSMONPSV_IER1_SSC_VREF_CORRUPT2_SHIFT   23
#define XSYSMONPSV_IER1_SSC_VREF_CORRUPT2_WIDTH   1
#define XSYSMONPSV_IER1_SSC_VREF_CORRUPT2_MASK    0X00800000

#define XSYSMONPSV_IER1_SSC_VREF_CORRUPT1_SHIFT   22
#define XSYSMONPSV_IER1_SSC_VREF_CORRUPT1_WIDTH   1
#define XSYSMONPSV_IER1_SSC_VREF_CORRUPT1_MASK    0X00400000

#define XSYSMONPSV_IER1_SSC_VREF_CORRUPT0_SHIFT   21
#define XSYSMONPSV_IER1_SSC_VREF_CORRUPT0_WIDTH   1
#define XSYSMONPSV_IER1_SSC_VREF_CORRUPT0_MASK    0X00200000

#define XSYSMONPSV_IER1_SSC_MRKR_CORRUPT4_SHIFT   20
#define XSYSMONPSV_IER1_SSC_MRKR_CORRUPT4_WIDTH   1
#define XSYSMONPSV_IER1_SSC_MRKR_CORRUPT4_MASK    0X00100000

#define XSYSMONPSV_IER1_SSC_MRKR_CORRUPT3_SHIFT   19
#define XSYSMONPSV_IER1_SSC_MRKR_CORRUPT3_WIDTH   1
#define XSYSMONPSV_IER1_SSC_MRKR_CORRUPT3_MASK    0X00080000

#define XSYSMONPSV_IER1_SSC_MRKR_CORRUPT2_SHIFT   18
#define XSYSMONPSV_IER1_SSC_MRKR_CORRUPT2_WIDTH   1
#define XSYSMONPSV_IER1_SSC_MRKR_CORRUPT2_MASK    0X00040000

#define XSYSMONPSV_IER1_SSC_MRKR_CORRUPT1_SHIFT   17
#define XSYSMONPSV_IER1_SSC_MRKR_CORRUPT1_WIDTH   1
#define XSYSMONPSV_IER1_SSC_MRKR_CORRUPT1_MASK    0X00020000

#define XSYSMONPSV_IER1_SSC_MRKR_CORRUPT0_SHIFT   16
#define XSYSMONPSV_IER1_SSC_MRKR_CORRUPT0_WIDTH   1
#define XSYSMONPSV_IER1_SSC_MRKR_CORRUPT0_MASK    0X00010000

#define XSYSMONPSV_IER1_NEW_DATA3_SHIFT   15
#define XSYSMONPSV_IER1_NEW_DATA3_WIDTH   1
#define XSYSMONPSV_IER1_NEW_DATA3_MASK    0X00008000

#define XSYSMONPSV_IER1_NEW_DATA2_SHIFT   14
#define XSYSMONPSV_IER1_NEW_DATA2_WIDTH   1
#define XSYSMONPSV_IER1_NEW_DATA2_MASK    0X00004000

#define XSYSMONPSV_IER1_NEW_DATA1_SHIFT   13
#define XSYSMONPSV_IER1_NEW_DATA1_WIDTH   1
#define XSYSMONPSV_IER1_NEW_DATA1_MASK    0X00002000

#define XSYSMONPSV_IER1_NEW_DATA0_SHIFT   12
#define XSYSMONPSV_IER1_NEW_DATA0_WIDTH   1
#define XSYSMONPSV_IER1_NEW_DATA0_MASK    0X00001000

#define XSYSMONPSV_IER1_SECURE_EFUSE_DONE_SHIFT   11
#define XSYSMONPSV_IER1_SECURE_EFUSE_DONE_WIDTH   1
#define XSYSMONPSV_IER1_SECURE_EFUSE_DONE_MASK    0X00000800

#define XSYSMONPSV_IER1_SECURE_EFUSE_ERROR_SHIFT   10
#define XSYSMONPSV_IER1_SECURE_EFUSE_ERROR_WIDTH   1
#define XSYSMONPSV_IER1_SECURE_EFUSE_ERROR_MASK    0X00000400

#define XSYSMONPSV_IER1_TEMP_SHIFT   9
#define XSYSMONPSV_IER1_TEMP_WIDTH   1
#define XSYSMONPSV_IER1_TEMP_MASK    0X00000200

#define XSYSMONPSV_IER1_OT_SHIFT   8
#define XSYSMONPSV_IER1_OT_WIDTH   1
#define XSYSMONPSV_IER1_OT_MASK    0X00000100

#define XSYSMONPSV_IER1_ALARM7_SHIFT   7
#define XSYSMONPSV_IER1_ALARM7_WIDTH   1
#define XSYSMONPSV_IER1_ALARM7_MASK    0X00000080

#define XSYSMONPSV_IER1_ALARM6_SHIFT   6
#define XSYSMONPSV_IER1_ALARM6_WIDTH   1
#define XSYSMONPSV_IER1_ALARM6_MASK    0X00000040

#define XSYSMONPSV_IER1_ALARM5_SHIFT   5
#define XSYSMONPSV_IER1_ALARM5_WIDTH   1
#define XSYSMONPSV_IER1_ALARM5_MASK    0X00000020

#define XSYSMONPSV_IER1_ALARM4_SHIFT   4
#define XSYSMONPSV_IER1_ALARM4_WIDTH   1
#define XSYSMONPSV_IER1_ALARM4_MASK    0X00000010

#define XSYSMONPSV_IER1_ALARM3_SHIFT   3
#define XSYSMONPSV_IER1_ALARM3_WIDTH   1
#define XSYSMONPSV_IER1_ALARM3_MASK    0X00000008

#define XSYSMONPSV_IER1_ALARM2_SHIFT   2
#define XSYSMONPSV_IER1_ALARM2_WIDTH   1
#define XSYSMONPSV_IER1_ALARM2_MASK    0X00000004

#define XSYSMONPSV_IER1_ALARM1_SHIFT   1
#define XSYSMONPSV_IER1_ALARM1_WIDTH   1
#define XSYSMONPSV_IER1_ALARM1_MASK    0X00000002

#define XSYSMONPSV_IER1_ALARM0_SHIFT   0
#define XSYSMONPSV_IER1_ALARM0_WIDTH   1
#define XSYSMONPSV_IER1_ALARM0_MASK    0X00000001

/**
 * Register: XSYSMONPSV_IDR1
 */
#define XSYSMONPSV_IDR1_OFFSET     0X0000005C

#define XSYSMONPSV_IDR1_SSC_OVERFLOW_SHIFT   31
#define XSYSMONPSV_IDR1_SSC_OVERFLOW_WIDTH   1
#define XSYSMONPSV_IDR1_SSC_OVERFLOW_MASK    0X80000000

#define XSYSMONPSV_IDR1_AXI_TIMEOUT_SHIFT   30
#define XSYSMONPSV_IDR1_AXI_TIMEOUT_WIDTH   1
#define XSYSMONPSV_IDR1_AXI_TIMEOUT_MASK    0X40000000

#define XSYSMONPSV_IDR1_EXT_REF_DOWN_SHIFT   29
#define XSYSMONPSV_IDR1_EXT_REF_DOWN_WIDTH   1
#define XSYSMONPSV_IDR1_EXT_REF_DOWN_MASK    0X20000000

#define XSYSMONPSV_IDR1_GOQ_DONE_SHIFT   28
#define XSYSMONPSV_IDR1_GOQ_DONE_WIDTH   1
#define XSYSMONPSV_IDR1_GOQ_DONE_MASK    0X10000000

#define XSYSMONPSV_IDR1_AXI_ERROR_RESPONSE_SHIFT   27
#define XSYSMONPSV_IDR1_AXI_ERROR_RESPONSE_WIDTH   1
#define XSYSMONPSV_IDR1_AXI_ERROR_RESPONSE_MASK    0X08000000

#define XSYSMONPSV_IDR1_AXI_BUFF_OVERFLOW_SHIFT   26
#define XSYSMONPSV_IDR1_AXI_BUFF_OVERFLOW_WIDTH   1
#define XSYSMONPSV_IDR1_AXI_BUFF_OVERFLOW_MASK    0X04000000

#define XSYSMONPSV_IDR1_SSC_VREF_CORRUPT4_SHIFT   25
#define XSYSMONPSV_IDR1_SSC_VREF_CORRUPT4_WIDTH   1
#define XSYSMONPSV_IDR1_SSC_VREF_CORRUPT4_MASK    0X02000000

#define XSYSMONPSV_IDR1_SSC_VREF_CORRUPT3_SHIFT   24
#define XSYSMONPSV_IDR1_SSC_VREF_CORRUPT3_WIDTH   1
#define XSYSMONPSV_IDR1_SSC_VREF_CORRUPT3_MASK    0X01000000

#define XSYSMONPSV_IDR1_SSC_VREF_CORRUPT2_SHIFT   23
#define XSYSMONPSV_IDR1_SSC_VREF_CORRUPT2_WIDTH   1
#define XSYSMONPSV_IDR1_SSC_VREF_CORRUPT2_MASK    0X00800000

#define XSYSMONPSV_IDR1_SSC_VREF_CORRUPT1_SHIFT   22
#define XSYSMONPSV_IDR1_SSC_VREF_CORRUPT1_WIDTH   1
#define XSYSMONPSV_IDR1_SSC_VREF_CORRUPT1_MASK    0X00400000

#define XSYSMONPSV_IDR1_SSC_VREF_CORRUPT0_SHIFT   21
#define XSYSMONPSV_IDR1_SSC_VREF_CORRUPT0_WIDTH   1
#define XSYSMONPSV_IDR1_SSC_VREF_CORRUPT0_MASK    0X00200000

#define XSYSMONPSV_IDR1_SSC_MRKR_CORRUPT4_SHIFT   20
#define XSYSMONPSV_IDR1_SSC_MRKR_CORRUPT4_WIDTH   1
#define XSYSMONPSV_IDR1_SSC_MRKR_CORRUPT4_MASK    0X00100000

#define XSYSMONPSV_IDR1_SSC_MRKR_CORRUPT3_SHIFT   19
#define XSYSMONPSV_IDR1_SSC_MRKR_CORRUPT3_WIDTH   1
#define XSYSMONPSV_IDR1_SSC_MRKR_CORRUPT3_MASK    0X00080000

#define XSYSMONPSV_IDR1_SSC_MRKR_CORRUPT2_SHIFT   18
#define XSYSMONPSV_IDR1_SSC_MRKR_CORRUPT2_WIDTH   1
#define XSYSMONPSV_IDR1_SSC_MRKR_CORRUPT2_MASK    0X00040000

#define XSYSMONPSV_IDR1_SSC_MRKR_CORRUPT1_SHIFT   17
#define XSYSMONPSV_IDR1_SSC_MRKR_CORRUPT1_WIDTH   1
#define XSYSMONPSV_IDR1_SSC_MRKR_CORRUPT1_MASK    0X00020000

#define XSYSMONPSV_IDR1_SSC_MRKR_CORRUPT0_SHIFT   16
#define XSYSMONPSV_IDR1_SSC_MRKR_CORRUPT0_WIDTH   1
#define XSYSMONPSV_IDR1_SSC_MRKR_CORRUPT0_MASK    0X00010000

#define XSYSMONPSV_IDR1_NEW_DATA3_SHIFT   15
#define XSYSMONPSV_IDR1_NEW_DATA3_WIDTH   1
#define XSYSMONPSV_IDR1_NEW_DATA3_MASK    0X00008000

#define XSYSMONPSV_IDR1_NEW_DATA2_SHIFT   14
#define XSYSMONPSV_IDR1_NEW_DATA2_WIDTH   1
#define XSYSMONPSV_IDR1_NEW_DATA2_MASK    0X00004000

#define XSYSMONPSV_IDR1_NEW_DATA1_SHIFT   13
#define XSYSMONPSV_IDR1_NEW_DATA1_WIDTH   1
#define XSYSMONPSV_IDR1_NEW_DATA1_MASK    0X00002000

#define XSYSMONPSV_IDR1_NEW_DATA0_SHIFT   12
#define XSYSMONPSV_IDR1_NEW_DATA0_WIDTH   1
#define XSYSMONPSV_IDR1_NEW_DATA0_MASK    0X00001000

#define XSYSMONPSV_IDR1_SECURE_EFUSE_DONE_SHIFT   11
#define XSYSMONPSV_IDR1_SECURE_EFUSE_DONE_WIDTH   1
#define XSYSMONPSV_IDR1_SECURE_EFUSE_DONE_MASK    0X00000800

#define XSYSMONPSV_IDR1_SECURE_EFUSE_ERROR_SHIFT   10
#define XSYSMONPSV_IDR1_SECURE_EFUSE_ERROR_WIDTH   1
#define XSYSMONPSV_IDR1_SECURE_EFUSE_ERROR_MASK    0X00000400

#define XSYSMONPSV_IDR1_TEMP_SHIFT   9
#define XSYSMONPSV_IDR1_TEMP_WIDTH   1
#define XSYSMONPSV_IDR1_TEMP_MASK    0X00000200

#define XSYSMONPSV_IDR1_OT_SHIFT   8
#define XSYSMONPSV_IDR1_OT_WIDTH   1
#define XSYSMONPSV_IDR1_OT_MASK    0X00000100

#define XSYSMONPSV_IDR1_ALARM7_SHIFT   7
#define XSYSMONPSV_IDR1_ALARM7_WIDTH   1
#define XSYSMONPSV_IDR1_ALARM7_MASK    0X00000080

#define XSYSMONPSV_IDR1_ALARM6_SHIFT   6
#define XSYSMONPSV_IDR1_ALARM6_WIDTH   1
#define XSYSMONPSV_IDR1_ALARM6_MASK    0X00000040

#define XSYSMONPSV_IDR1_ALARM5_SHIFT   5
#define XSYSMONPSV_IDR1_ALARM5_WIDTH   1
#define XSYSMONPSV_IDR1_ALARM5_MASK    0X00000020

#define XSYSMONPSV_IDR1_ALARM4_SHIFT   4
#define XSYSMONPSV_IDR1_ALARM4_WIDTH   1
#define XSYSMONPSV_IDR1_ALARM4_MASK    0X00000010

#define XSYSMONPSV_IDR1_ALARM3_SHIFT   3
#define XSYSMONPSV_IDR1_ALARM3_WIDTH   1
#define XSYSMONPSV_IDR1_ALARM3_MASK    0X00000008

#define XSYSMONPSV_IDR1_ALARM2_SHIFT   2
#define XSYSMONPSV_IDR1_ALARM2_WIDTH   1
#define XSYSMONPSV_IDR1_ALARM2_MASK    0X00000004

#define XSYSMONPSV_IDR1_ALARM1_SHIFT   1
#define XSYSMONPSV_IDR1_ALARM1_WIDTH   1
#define XSYSMONPSV_IDR1_ALARM1_MASK    0X00000002

#define XSYSMONPSV_IDR1_ALARM0_SHIFT   0
#define XSYSMONPSV_IDR1_ALARM0_WIDTH   1
#define XSYSMONPSV_IDR1_ALARM0_MASK    0X00000001

/**
 * Register: XSYSMONPSV_IOR
 */
#define XSYSMONPSV_IOR     0X00000060

#define XSYSMONPSV_IOR_OFFSET_SHIFT   0
#define XSYSMONPSV_IOR_OFFSET_WIDTH   5
#define XSYSMONPSV_IOR_OFFSET_MASK    0X0000001F

/**
 * Register: XSYSMONPSV_CONFIG0
 */
#define XSYSMONPSV_CONFIG0     0X00000100

#define XSYSMONPSV_CONFIG0_TEMP_AVERAGE_SHIFT   24
#define XSYSMONPSV_CONFIG0_TEMP_AVERAGE_WIDTH   4
#define XSYSMONPSV_CONFIG0_TEMP_AVERAGE_MASK    0X0F000000

#define XSYSMONPSV_CONFIG0_RESERVED2_SHIFT   23
#define XSYSMONPSV_CONFIG0_RESERVED2_WIDTH   1
#define XSYSMONPSV_CONFIG0_RESERVED2_MASK    0X00800000

#define XSYSMONPSV_CONFIG0_TEMP_ALARM_WINDOW_EN_SHIFT   22
#define XSYSMONPSV_CONFIG0_TEMP_ALARM_WINDOW_EN_WIDTH   1
#define XSYSMONPSV_CONFIG0_TEMP_ALARM_WINDOW_EN_MASK    0X00400000

#define XSYSMONPSV_CONFIG0_AVERAGE_SHIFT   14
#define XSYSMONPSV_CONFIG0_AVERAGE_WIDTH   4
#define XSYSMONPSV_CONFIG0_AVERAGE_MASK    0X0003C000

#define XSYSMONPSV_CONFIG0_RESERVED1_SHIFT   10
#define XSYSMONPSV_CONFIG0_RESERVED1_WIDTH   4
#define XSYSMONPSV_CONFIG0_RESERVED1_MASK    0X00003C00

#define XSYSMONPSV_CONFIG0_I2C_NOT_PMBUS_SHIFT   9
#define XSYSMONPSV_CONFIG0_I2C_NOT_PMBUS_WIDTH   1
#define XSYSMONPSV_CONFIG0_I2C_NOT_PMBUS_MASK    0X00000200

#define XSYSMONPSV_CONFIG0_PMBUS_UNRESTRICTED_SHIFT   8
#define XSYSMONPSV_CONFIG0_PMBUS_UNRESTRICTED_WIDTH   1
#define XSYSMONPSV_CONFIG0_PMBUS_UNRESTRICTED_MASK    0X00000100

#define XSYSMONPSV_CONFIG0_PMBUS_ENABLE_SHIFT   7
#define XSYSMONPSV_CONFIG0_PMBUS_ENABLE_WIDTH   1
#define XSYSMONPSV_CONFIG0_PMBUS_ENABLE_MASK    0X00000080

#define XSYSMONPSV_CONFIG0_PMBUS_ADDRESS_SHIFT   0
#define XSYSMONPSV_CONFIG0_PMBUS_ADDRESS_WIDTH   7
#define XSYSMONPSV_CONFIG0_PMBUS_ADDRESS_MASK    0X0000007F

/**
 * Register: XSYSMONPSV_TOKEN_MNGR
 */
#define XSYSMONPSV_TOKEN_MNGR     0X00000104

#define XSYSMONPSV_TOKEN_MNGR_BYPASS_PL_SHIFT   20
#define XSYSMONPSV_TOKEN_MNGR_BYPASS_PL_WIDTH   1
#define XSYSMONPSV_TOKEN_MNGR_BYPASS_PL_MASK    0X00100000

#define XSYSMONPSV_TOKEN_MNGR_BYPASS_LPD_SHIFT   19
#define XSYSMONPSV_TOKEN_MNGR_BYPASS_LPD_WIDTH   1
#define XSYSMONPSV_TOKEN_MNGR_BYPASS_LPD_MASK    0X00080000

#define XSYSMONPSV_TOKEN_MNGR_BYPASS_FPD_SHIFT   18
#define XSYSMONPSV_TOKEN_MNGR_BYPASS_FPD_WIDTH   1
#define XSYSMONPSV_TOKEN_MNGR_BYPASS_FPD_MASK    0X00040000

#define XSYSMONPSV_TOKEN_MNGR_BYPASS_SAT1_SHIFT   17
#define XSYSMONPSV_TOKEN_MNGR_BYPASS_SAT1_WIDTH   1
#define XSYSMONPSV_TOKEN_MNGR_BYPASS_SAT1_MASK    0X00020000

#define XSYSMONPSV_TOKEN_MNGR_BYPASS_SAT0_SHIFT   16
#define XSYSMONPSV_TOKEN_MNGR_BYPASS_SAT0_WIDTH   1
#define XSYSMONPSV_TOKEN_MNGR_BYPASS_SAT0_MASK    0X00010000

#define XSYSMONPSV_TOKEN_MNGR_CTRL_TOKEN_COUNT_SHIFT   8
#define XSYSMONPSV_TOKEN_MNGR_CTRL_TOKEN_COUNT_WIDTH   8
#define XSYSMONPSV_TOKEN_MNGR_CTRL_TOKEN_COUNT_MASK    0X0000FF00

#define XSYSMONPSV_TOKEN_MNGR_VREF_TOKEN_COUNT_SHIFT   0
#define XSYSMONPSV_TOKEN_MNGR_VREF_TOKEN_COUNT_WIDTH   8
#define XSYSMONPSV_TOKEN_MNGR_VREF_TOKEN_COUNT_MASK    0X000000FF

/**
 * Register: XSYSMONPSV_VREF_SSC_COUNT1
 */
#define XSYSMONPSV_VREF_SSC_COUNT1     0X00000108

#define XSYSMONPSV_VREF_SSC_COUNT1_VAL_SHIFT   0
#define XSYSMONPSV_VREF_SSC_COUNT1_VAL_WIDTH   18
#define XSYSMONPSV_VREF_SSC_COUNT1_VAL_MASK    0X0003FFFF

/**
 * Register: XSYSMONPSV_VREF_SSC_COUNT2
 */
#define XSYSMONPSV_VREF_SSC_COUNT2     0X0000010C

#define XSYSMONPSV_VREF_SSC_COUNT2_VAL_SHIFT   0
#define XSYSMONPSV_VREF_SSC_COUNT2_VAL_WIDTH   18
#define XSYSMONPSV_VREF_SSC_COUNT2_VAL_MASK    0X0003FFFF

/**
 * Register: XSYSMONPSV_VREF_SSC_COUNT3
 */
#define XSYSMONPSV_VREF_SSC_COUNT3     0X00000110

#define XSYSMONPSV_VREF_SSC_COUNT3_VAL_SHIFT   0
#define XSYSMONPSV_VREF_SSC_COUNT3_VAL_WIDTH   18
#define XSYSMONPSV_VREF_SSC_COUNT3_VAL_MASK    0X0003FFFF

/**
 * Register: XSYSMONPSV_VREF_SSC_COUNT4
 */
#define XSYSMONPSV_VREF_SSC_COUNT4     0X00000114

#define XSYSMONPSV_VREF_SSC_COUNT4_VAL_SHIFT   0
#define XSYSMONPSV_VREF_SSC_COUNT4_VAL_WIDTH   18
#define XSYSMONPSV_VREF_SSC_COUNT4_VAL_MASK    0X0003FFFF

/**
 * Register: XSYSMONPSV_GOQ_CONFIG
 */
#define XSYSMONPSV_GOQ_CONFIG     0X00000118

#define XSYSMONPSV_GOQ_CONFIG_VDAC_SEL_SHIFT   9
#define XSYSMONPSV_GOQ_CONFIG_VDAC_SEL_WIDTH   7
#define XSYSMONPSV_GOQ_CONFIG_VDAC_SEL_MASK    0X0000FE00

#define XSYSMONPSV_GOQ_CONFIG_EN_RCAL_SHIFT   8
#define XSYSMONPSV_GOQ_CONFIG_EN_RCAL_WIDTH   1
#define XSYSMONPSV_GOQ_CONFIG_EN_RCAL_MASK    0X00000100

#define XSYSMONPSV_GOQ_CONFIG_NUM_HITS_SHIFT   1
#define XSYSMONPSV_GOQ_CONFIG_NUM_HITS_WIDTH   7
#define XSYSMONPSV_GOQ_CONFIG_NUM_HITS_MASK    0X000000FE

#define XSYSMONPSV_GOQ_CONFIG_GOQ_MODE_SHIFT   0
#define XSYSMONPSV_GOQ_CONFIG_GOQ_MODE_WIDTH   1
#define XSYSMONPSV_GOQ_CONFIG_GOQ_MODE_MASK    0X00000001

/**
 * Register: XSYSMONPSV_METAL_OPTION_OVERRIDES
 */
#define XSYSMONPSV_METAL_OPTION_OVERRIDES     0X0000011C

#define XSYSMONPSV_METAL_OPTION_OVERRIDES_MO_BYPASS_EN_SHIFT   25
#define XSYSMONPSV_METAL_OPTION_OVERRIDES_MO_BYPASS_EN_WIDTH   1
#define XSYSMONPSV_METAL_OPTION_OVERRIDES_MO_BYPASS_EN_MASK    0X02000000

#define XSYSMONPSV_METAL_OPTION_OVERRIDES_MO_CUR_COR_EN_B_SHIFT   24
#define XSYSMONPSV_METAL_OPTION_OVERRIDES_MO_CUR_COR_EN_B_WIDTH   1
#define XSYSMONPSV_METAL_OPTION_OVERRIDES_MO_CUR_COR_EN_B_MASK    0X01000000

#define XSYSMONPSV_METAL_OPTION_OVERRIDES_MO_VREF_CURVE_COR_SHIFT   8
#define XSYSMONPSV_METAL_OPTION_OVERRIDES_MO_VREF_CURVE_COR_WIDTH   16
#define XSYSMONPSV_METAL_OPTION_OVERRIDES_MO_VREF_CURVE_COR_MASK    0X00FFFF00

#define XSYSMONPSV_METAL_OPTION_OVERRIDES_MO_SPARE_SHIFT   0
#define XSYSMONPSV_METAL_OPTION_OVERRIDES_MO_SPARE_WIDTH   8
#define XSYSMONPSV_METAL_OPTION_OVERRIDES_MO_SPARE_MASK    0X000000FF

/**
 * Register: XSYSMONPSV_GREF_MODE_SETTING
 */
#define XSYSMONPSV_GREF_MODE_SETTING     0X00000120

#define XSYSMONPSV_GREF_MODE_SETTING_FABRIC_MODE_SHIFT   10
#define XSYSMONPSV_GREF_MODE_SETTING_FABRIC_MODE_WIDTH   1
#define XSYSMONPSV_GREF_MODE_SETTING_FABRIC_MODE_MASK    0X00000400

#define XSYSMONPSV_GREF_MODE_SETTING_SECURE_MODE_SHIFT   9
#define XSYSMONPSV_GREF_MODE_SETTING_SECURE_MODE_WIDTH   1
#define XSYSMONPSV_GREF_MODE_SETTING_SECURE_MODE_MASK    0X00000200

#define XSYSMONPSV_GREF_MODE_SETTING_TRIM_MODE_SHIFT   8
#define XSYSMONPSV_GREF_MODE_SETTING_TRIM_MODE_WIDTH   1
#define XSYSMONPSV_GREF_MODE_SETTING_TRIM_MODE_MASK    0X00000100

#define XSYSMONPSV_GREF_MODE_SETTING_TRIM_SHIFT   4
#define XSYSMONPSV_GREF_MODE_SETTING_TRIM_WIDTH   4
#define XSYSMONPSV_GREF_MODE_SETTING_TRIM_MASK    0X000000F0

#define XSYSMONPSV_GREF_MODE_SETTING_GOQ_SHIFT   0
#define XSYSMONPSV_GREF_MODE_SETTING_GOQ_WIDTH   4
#define XSYSMONPSV_GREF_MODE_SETTING_GOQ_MASK    0X0000000F

/**
 * Register: XSYSMONPSV_AXI_BUFFER_BASE_HIGH
 */
#define XSYSMONPSV_AXI_BUFFER_BASE_HIGH     0X00000124

#define XSYSMONPSV_AXI_BUFFER_BASE_HIGH_VAL_SHIFT   0
#define XSYSMONPSV_AXI_BUFFER_BASE_HIGH_VAL_WIDTH   32
#define XSYSMONPSV_AXI_BUFFER_BASE_HIGH_VAL_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_AXI_BUFFER_OFFSET
 */
#define XSYSMONPSV_AXI_BUFFER_OFFSET     0X00000128

#define XSYSMONPSV_AXI_BUFFER_OFFSET_LAST_SHIFT   16
#define XSYSMONPSV_AXI_BUFFER_OFFSET_LAST_WIDTH   16
#define XSYSMONPSV_AXI_BUFFER_OFFSET_LAST_MASK    0XFFFF0000

#define XSYSMONPSV_AXI_BUFFER_OFFSET_FIRST_SHIFT   0
#define XSYSMONPSV_AXI_BUFFER_OFFSET_FIRST_WIDTH   16
#define XSYSMONPSV_AXI_BUFFER_OFFSET_FIRST_MASK    0X0000FFFF

/**
 * Register: XSYSMONPSV_TEST_ANA_CTRL0
 */
#define XSYSMONPSV_TEST_ANA_CTRL0     0X00000134

#define XSYSMONPSV_TEST_ANA_CTRL0_VAL_SHIFT   0
#define XSYSMONPSV_TEST_ANA_CTRL0_VAL_WIDTH   32
#define XSYSMONPSV_TEST_ANA_CTRL0_VAL_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_TEST_ANA_CTRL1
 */
#define XSYSMONPSV_TEST_ANA_CTRL1     0X00000138

#define XSYSMONPSV_TEST_ANA_CTRL1_VAL_SHIFT   0
#define XSYSMONPSV_TEST_ANA_CTRL1_VAL_WIDTH   32
#define XSYSMONPSV_TEST_ANA_CTRL1_VAL_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_TEST_REG0
 */
#define XSYSMONPSV_TEST_REG0     0X0000013C

#define XSYSMONPSV_TEST_REG0_FABRIC_SEL_REG_SHIFT   0
#define XSYSMONPSV_TEST_REG0_FABRIC_SEL_REG_WIDTH   2
#define XSYSMONPSV_TEST_REG0_FABRIC_SEL_REG_MASK    0X00000003

/**
 * Register: XSYSMONPSV_DFX_REG0
 */
#define XSYSMONPSV_DFX_REG0     0X0000015C

#define XSYSMONPSV_DFX_REG0_DFX_CSSD_TRIG_SHIFT   0
#define XSYSMONPSV_DFX_REG0_DFX_CSSD_TRIG_WIDTH   2
#define XSYSMONPSV_DFX_REG0_DFX_CSSD_TRIG_MASK    0X00000003

/**
 * Register: XSYSMONPSV_EFUSE_REG0
 */
#define XSYSMONPSV_EFUSE_REG0     0X0000016C

#define XSYSMONPSV_EFUSE_REG0_VAL_SHIFT   0
#define XSYSMONPSV_EFUSE_REG0_VAL_WIDTH   32
#define XSYSMONPSV_EFUSE_REG0_VAL_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_EFUSE_REG1
 */
#define XSYSMONPSV_EFUSE_REG1     0X00000170

#define XSYSMONPSV_EFUSE_REG1_VAL_SHIFT   0
#define XSYSMONPSV_EFUSE_REG1_VAL_WIDTH   32
#define XSYSMONPSV_EFUSE_REG1_VAL_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_EFUSE_REG2
 */
#define XSYSMONPSV_EFUSE_REG2     0X00000174

#define XSYSMONPSV_EFUSE_REG2_VAL_SHIFT   0
#define XSYSMONPSV_EFUSE_REG2_VAL_WIDTH   32
#define XSYSMONPSV_EFUSE_REG2_VAL_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_EFUSE_REG3
 */
#define XSYSMONPSV_EFUSE_REG3     0X00000178

#define XSYSMONPSV_EFUSE_REG3_VAL_SHIFT   0
#define XSYSMONPSV_EFUSE_REG3_VAL_WIDTH   19
#define XSYSMONPSV_EFUSE_REG3_VAL_MASK    0X0007FFFF

/**
 * Register: XSYSMONPSV_IXPCM_CONF_READY
 */
#define XSYSMONPSV_IXPCM_CONF_READY     0X0000017C

#define XSYSMONPSV_IXPCM_CONF_READY_VALUE_SHIFT   0
#define XSYSMONPSV_IXPCM_CONF_READY_VALUE_WIDTH   1
#define XSYSMONPSV_IXPCM_CONF_READY_VALUE_MASK    0X00000001

/**
 * Register: XSYSMONPSV_IXPCM_CONF
 */
#define XSYSMONPSV_IXPCM_CONF     0X00000180

#define XSYSMONPSV_IXPCM_CONF_RADDR_IXPCM_SHIFT   8
#define XSYSMONPSV_IXPCM_CONF_RADDR_IXPCM_WIDTH   9
#define XSYSMONPSV_IXPCM_CONF_RADDR_IXPCM_MASK    0X0001FF00

#define XSYSMONPSV_IXPCM_CONF_DELAY_SHIFT   2
#define XSYSMONPSV_IXPCM_CONF_DELAY_WIDTH   6
#define XSYSMONPSV_IXPCM_CONF_DELAY_MASK    0X000000FC

#define XSYSMONPSV_IXPCM_CONF_MODE_SHIFT   1
#define XSYSMONPSV_IXPCM_CONF_MODE_WIDTH   1
#define XSYSMONPSV_IXPCM_CONF_MODE_MASK    0X00000002

#define XSYSMONPSV_IXPCM_CONF_ENABLE_SHIFT   0
#define XSYSMONPSV_IXPCM_CONF_ENABLE_WIDTH   1
#define XSYSMONPSV_IXPCM_CONF_ENABLE_MASK    0X00000001

/**
 * Register: XSYSMONPSV_IXPCM_MEAS_CONF_0
 */
#define XSYSMONPSV_IXPCM_MEAS_CONF_0     0X00000184

#define XSYSMONPSV_IXPCM_MEAS_CONF_0_SPARE_SHIFT   27
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_SPARE_WIDTH   5
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_SPARE_MASK    0XF8000000

#define XSYSMONPSV_IXPCM_MEAS_CONF_0_VDAC1_CODE_SHIFT   20
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_VDAC1_CODE_WIDTH   7
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_VDAC1_CODE_MASK    0X07F00000

#define XSYSMONPSV_IXPCM_MEAS_CONF_0_VDAC2_CODE_SHIFT   13
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_VDAC2_CODE_WIDTH   7
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_VDAC2_CODE_MASK    0X000FE000

#define XSYSMONPSV_IXPCM_MEAS_CONF_0_VDAC_REF_SHIFT   12
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_VDAC_REF_WIDTH   1
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_VDAC_REF_MASK    0X00001000

#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_SENSE_RIDSAT_B_SHIFT   11
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_SENSE_RIDSAT_B_WIDTH   1
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_SENSE_RIDSAT_B_MASK    0X00000800

#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_SENSE_RIDSAT_A_SHIFT   10
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_SENSE_RIDSAT_A_WIDTH   1
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_SENSE_RIDSAT_A_MASK    0X00000400

#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_RIDSAT_B_SHIFT   9
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_RIDSAT_B_WIDTH   1
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_RIDSAT_B_MASK    0X00000200

#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_RIDSAT_A_SHIFT   8
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_RIDSAT_A_WIDTH   1
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_RIDSAT_A_MASK    0X00000100

#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_IDSAT_SHIFT   7
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_IDSAT_WIDTH   1
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_IDSAT_MASK    0X00000080

#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_RVTSAT_RESD_SHIFT   6
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_RVTSAT_RESD_WIDTH   1
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_RVTSAT_RESD_MASK    0X00000040

#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_RVTSAT_RESC_SHIFT   5
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_RVTSAT_RESC_WIDTH   1
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_RVTSAT_RESC_MASK    0X00000020

#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_RVTSAT_RESB_SHIFT   4
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_RVTSAT_RESB_WIDTH   1
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_RVTSAT_RESB_MASK    0X00000010

#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_RVTSAT_RESA_SHIFT   3
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_RVTSAT_RESA_WIDTH   1
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_RVTSAT_RESA_MASK    0X00000008

#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_VTSAT_DUT_SHIFT   2
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_VTSAT_DUT_WIDTH   1
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_VTSAT_DUT_MASK    0X00000004

#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_VTSAT_ID_SHIFT   1
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_VTSAT_ID_WIDTH   1
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_VTSAT_ID_MASK    0X00000002

#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_VTSAT_SHIFT   0
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_VTSAT_WIDTH   1
#define XSYSMONPSV_IXPCM_MEAS_CONF_0_EN_VTSAT_MASK    0X00000001

/**
 * Register: XSYSMONPSV_IXPCM_MEAS_CONF_1
 */
#define XSYSMONPSV_IXPCM_MEAS_CONF_1     0X00000188

#define XSYSMONPSV_IXPCM_MEAS_CONF_1_SPARE_SHIFT   27
#define XSYSMONPSV_IXPCM_MEAS_CONF_1_SPARE_WIDTH   5
#define XSYSMONPSV_IXPCM_MEAS_CONF_1_SPARE_MASK    0XF8000000

#define XSYSMONPSV_IXPCM_MEAS_CONF_1_EN_SET_SHIFT   19
#define XSYSMONPSV_IXPCM_MEAS_CONF_1_EN_SET_WIDTH   8
#define XSYSMONPSV_IXPCM_MEAS_CONF_1_EN_SET_MASK    0X07F80000

#define XSYSMONPSV_IXPCM_MEAS_CONF_1_EN_DUT_SHIFT   3
#define XSYSMONPSV_IXPCM_MEAS_CONF_1_EN_DUT_WIDTH   16
#define XSYSMONPSV_IXPCM_MEAS_CONF_1_EN_DUT_MASK    0X0007FFF8

#define XSYSMONPSV_IXPCM_MEAS_CONF_1_EN_SENSE_GATE_SHIFT   2
#define XSYSMONPSV_IXPCM_MEAS_CONF_1_EN_SENSE_GATE_WIDTH   1
#define XSYSMONPSV_IXPCM_MEAS_CONF_1_EN_SENSE_GATE_MASK    0X00000004

#define XSYSMONPSV_IXPCM_MEAS_CONF_1_EN_SENSE_SOURCE_SHIFT   1
#define XSYSMONPSV_IXPCM_MEAS_CONF_1_EN_SENSE_SOURCE_WIDTH   1
#define XSYSMONPSV_IXPCM_MEAS_CONF_1_EN_SENSE_SOURCE_MASK    0X00000002

#define XSYSMONPSV_IXPCM_MEAS_CONF_1_EN_SENSE_DRAIN_SHIFT   0
#define XSYSMONPSV_IXPCM_MEAS_CONF_1_EN_SENSE_DRAIN_WIDTH   1
#define XSYSMONPSV_IXPCM_MEAS_CONF_1_EN_SENSE_DRAIN_MASK    0X00000001

/**
 * Register: XSYSMONPSV_NEW_DATA_FLAG0
 */
#define XSYSMONPSV_NEW_DATA_FLAG0     0X00001000

#define XSYSMONPSV_NEW_DATA_FLAG0_SUPPLY_31_0_SHIFT   0
#define XSYSMONPSV_NEW_DATA_FLAG0_SUPPLY_31_0_WIDTH   32
#define XSYSMONPSV_NEW_DATA_FLAG0_SUPPLY_31_0_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_NEW_DATA_FLAG1
 */
#define XSYSMONPSV_NEW_DATA_FLAG1     0X00001004

#define XSYSMONPSV_NEW_DATA_FLAG1_SUPPLY_63_32_SHIFT   0
#define XSYSMONPSV_NEW_DATA_FLAG1_SUPPLY_63_32_WIDTH   32
#define XSYSMONPSV_NEW_DATA_FLAG1_SUPPLY_63_32_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_NEW_DATA_FLAG2
 */
#define XSYSMONPSV_NEW_DATA_FLAG2     0X00001008

#define XSYSMONPSV_NEW_DATA_FLAG2_SUPPLY_95_64_SHIFT   0
#define XSYSMONPSV_NEW_DATA_FLAG2_SUPPLY_95_64_WIDTH   32
#define XSYSMONPSV_NEW_DATA_FLAG2_SUPPLY_95_64_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_NEW_DATA_FLAG3
 */
#define XSYSMONPSV_NEW_DATA_FLAG3     0X0000100C

#define XSYSMONPSV_NEW_DATA_FLAG3_SUPPLY_127_96_SHIFT   0
#define XSYSMONPSV_NEW_DATA_FLAG3_SUPPLY_127_96_WIDTH   32
#define XSYSMONPSV_NEW_DATA_FLAG3_SUPPLY_127_96_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_NEW_DATA_FLAG4
 */
#define XSYSMONPSV_NEW_DATA_FLAG4     0X00001010

#define XSYSMONPSV_NEW_DATA_FLAG4_SUPPLY_159_128_SHIFT   0
#define XSYSMONPSV_NEW_DATA_FLAG4_SUPPLY_159_128_WIDTH   32
#define XSYSMONPSV_NEW_DATA_FLAG4_SUPPLY_159_128_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_ALARM_FLAG0
 */
#define XSYSMONPSV_ALARM_FLAG0     0X00001018

#define XSYSMONPSV_ALARM_FLAG0_SUPPLY_31_0_SHIFT   0
#define XSYSMONPSV_ALARM_FLAG0_SUPPLY_31_0_WIDTH   32
#define XSYSMONPSV_ALARM_FLAG0_SUPPLY_31_0_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_ALARM_FLAG1
 */
#define XSYSMONPSV_ALARM_FLAG1     0X0000101C

#define XSYSMONPSV_ALARM_FLAG1_SUPPLY_63_32_SHIFT   0
#define XSYSMONPSV_ALARM_FLAG1_SUPPLY_63_32_WIDTH   32
#define XSYSMONPSV_ALARM_FLAG1_SUPPLY_63_32_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_ALARM_FLAG2
 */
#define XSYSMONPSV_ALARM_FLAG2     0X00001020

#define XSYSMONPSV_ALARM_FLAG2_SUPPLY_95_64_SHIFT   0
#define XSYSMONPSV_ALARM_FLAG2_SUPPLY_95_64_WIDTH   32
#define XSYSMONPSV_ALARM_FLAG2_SUPPLY_95_64_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_ALARM_FLAG3
 */
#define XSYSMONPSV_ALARM_FLAG3     0X00001024

#define XSYSMONPSV_ALARM_FLAG3_SUPPLY_127_96_SHIFT   0
#define XSYSMONPSV_ALARM_FLAG3_SUPPLY_127_96_WIDTH   32
#define XSYSMONPSV_ALARM_FLAG3_SUPPLY_127_96_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_ALARM_FLAG4
 */
#define XSYSMONPSV_ALARM_FLAG4     0X00001028

#define XSYSMONPSV_ALARM_FLAG4_SUPPLY_159_128_SHIFT   0
#define XSYSMONPSV_ALARM_FLAG4_SUPPLY_159_128_WIDTH   32
#define XSYSMONPSV_ALARM_FLAG4_SUPPLY_159_128_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_DEVICE_TEMP_MAX
 */
#define XSYSMONPSV_DEVICE_TEMP_MAX     0X00001030

#define XSYSMONPSV_DEVICE_TEMP_MAX_VAL_SHIFT   0
#define XSYSMONPSV_DEVICE_TEMP_MAX_VAL_WIDTH   16
#define XSYSMONPSV_DEVICE_TEMP_MAX_VAL_MASK    0X0000FFFF

/**
 * Register: XSYSMONPSV_DEVICE_TEMP_MIN
 */
#define XSYSMONPSV_DEVICE_TEMP_MIN     0X00001034

#define XSYSMONPSV_DEVICE_TEMP_MIN_VAL_SHIFT   0
#define XSYSMONPSV_DEVICE_TEMP_MIN_VAL_WIDTH   16
#define XSYSMONPSV_DEVICE_TEMP_MIN_VAL_MASK    0X0000FFFF

/**
 * Register: XSYSMONPSV_TEMP_FPD
 */
#define XSYSMONPSV_TEMP_FPD     0X00001038

#define XSYSMONPSV_TEMP_FPD_VAL_SHIFT   0
#define XSYSMONPSV_TEMP_FPD_VAL_WIDTH   16
#define XSYSMONPSV_TEMP_FPD_VAL_MASK    0X0000FFFF

/**
 * Register: XSYSMONPSV_TEMP_LPD
 */
#define XSYSMONPSV_TEMP_LPD     0X0000103C

#define XSYSMONPSV_TEMP_LPD_VAL_SHIFT   0
#define XSYSMONPSV_TEMP_LPD_VAL_WIDTH   16
#define XSYSMONPSV_TEMP_LPD_VAL_MASK    0X0000FFFF
/**
 * Supply format macros
 */
#define XSYSMONPSV_SUPPLY_MANTISSA_MASK		0x0000FFFF
#define XSYSMONPSV_SUPPLY_FMT_MASK		0x00010000
#define XSYSMONPSV_SUPPLY_FMT_SHIFT		16
#define XSYSMONPSV_SUPPLY_MODE_MASK		0x00060000
#define XSYSMONPSV_SUPPLY_MODE_SHIFT		17
#define XSYSMONPSV_SUPPLY_MANTISSA_SIGN		15


/**
 * Register: XSYSMONPSV_SUPPLY
 */
#define XSYSMONPSV_SUPPLY     0X00001040

#define XSYSMONPSV_SUPPLY_VAL_SHIFT   0
#define XSYSMONPSV_SUPPLY_VAL_WIDTH   19
#define XSYSMONPSV_SUPPLY_VAL_MASK    0X0007FFFF

/**
 * Register: XSYSMONPSV_SUPPLY_MIN
 */
#define XSYSMONPSV_SUPPLY_MIN    0X00001340

#define XSYSMONPSV_SUPPLY_MIN_VAL_SHIFT   0
#define XSYSMONPSV_SUPPLY_MIN_VAL_WIDTH   19
#define XSYSMONPSV_SUPPLY_MIN_VAL_MASK    0X0007FFFF

/**
 * Register: XSYSMONPSV_SUPPLY_MAX
 */
#define XSYSMONPSV_SUPPLY_MAX    0X00001640

#define XSYSMONPSV_SUPPLY_MAX_VAL_SHIFT   0
#define XSYSMONPSV_SUPPLY_MAX_VAL_WIDTH   19
#define XSYSMONPSV_SUPPLY_MAX_VAL_MASK    0X0007FFFF

/**
 * Register: XSYSMONPSV_ALARM_REG0
 */
#define XSYSMONPSV_ALARM_REG0    0X00001940

#define XSYSMONPSV_ALARM_REG0_VAL_SHIFT   0
#define XSYSMONPSV_ALARM_REG0_VAL_WIDTH   32
#define XSYSMONPSV_ALARM_REG0_VAL_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_ALARM_REG1
 */
#define XSYSMONPSV_ALARM_REG1    0X00001944

#define XSYSMONPSV_ALARM_REG1_VAL_SHIFT   0
#define XSYSMONPSV_ALARM_REG1_VAL_WIDTH   32
#define XSYSMONPSV_ALARM_REG1_VAL_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_ALARM_REG2
 */
#define XSYSMONPSV_ALARM_REG2    0X00001948

#define XSYSMONPSV_ALARM_REG2_VAL_SHIFT   0
#define XSYSMONPSV_ALARM_REG2_VAL_WIDTH   32
#define XSYSMONPSV_ALARM_REG2_VAL_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_ALARM_REG3
 */
#define XSYSMONPSV_ALARM_REG3    0X0000194C

#define XSYSMONPSV_ALARM_REG3_VAL_SHIFT   0
#define XSYSMONPSV_ALARM_REG3_VAL_WIDTH   32
#define XSYSMONPSV_ALARM_REG3_VAL_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_ALARM_REG4
 */
#define XSYSMONPSV_ALARM_REG4    0X00001950

#define XSYSMONPSV_ALARM_REG4_VAL_SHIFT   0
#define XSYSMONPSV_ALARM_REG4_VAL_WIDTH   32
#define XSYSMONPSV_ALARM_REG4_VAL_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_EN_AVG_REG0
 */
#define XSYSMONPSV_EN_AVG_REG0    0X00001958

#define XSYSMONPSV_EN_AVG_REG0_VAL_SHIFT   0
#define XSYSMONPSV_EN_AVG_REG0_VAL_WIDTH   32
#define XSYSMONPSV_EN_AVG_REG0_VAL_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_EN_AVG_REG1
 */
#define XSYSMONPSV_EN_AVG_REG1    0X0000195C

#define XSYSMONPSV_EN_AVG_REG1_VAL_SHIFT   0
#define XSYSMONPSV_EN_AVG_REG1_VAL_WIDTH   32
#define XSYSMONPSV_EN_AVG_REG1_VAL_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_EN_AVG_REG2
 */
#define XSYSMONPSV_EN_AVG_REG2    0X00001960

#define XSYSMONPSV_EN_AVG_REG2_VAL_SHIFT   0
#define XSYSMONPSV_EN_AVG_REG2_VAL_WIDTH   32
#define XSYSMONPSV_EN_AVG_REG2_VAL_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_EN_AVG_REG3
 */
#define XSYSMONPSV_EN_AVG_REG3    0X00001964

#define XSYSMONPSV_EN_AVG_REG3_VAL_SHIFT   0
#define XSYSMONPSV_EN_AVG_REG3_VAL_WIDTH   32
#define XSYSMONPSV_EN_AVG_REG3_VAL_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_EN_AVG_REG4
 */
#define XSYSMONPSV_EN_AVG_REG4    0X00001968

#define XSYSMONPSV_EN_AVG_REG4_VAL_SHIFT   0
#define XSYSMONPSV_EN_AVG_REG4_VAL_WIDTH   32
#define XSYSMONPSV_EN_AVG_REG4_VAL_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_DEVICE_TEMP_TH
 */
#define XSYSMONPSV_DEVICE_TEMP_TH    0X00001970

#define XSYSMONPSV_DEVICE_TEMP_TH_VAL_SHIFT   0
#define XSYSMONPSV_DEVICE_TEMP_TH_VAL_WIDTH   16
#define XSYSMONPSV_DEVICE_TEMP_TH_VAL_MASK    0X0000FFFF

/**
 * Register: XSYSMONPSV_OT_TEMP_TH
 */
#define XSYSMONPSV_OT_TEMP_TH    0X00001978

#define XSYSMONPSV_OT_TEMP_TH_VAL_SHIFT   0
#define XSYSMONPSV_OT_TEMP_TH_VAL_WIDTH   16
#define XSYSMONPSV_OT_TEMP_TH_VAL_MASK    0X0000FFFF

/**
 * Register: XSYSMONPSV_SUPPLY_TH_LOWER
 */
#define XSYSMONPSV_SUPPLY_TH_LOWER    0X00001980

#define XSYSMONPSV_SUPPLY_TH_LOWER_VAL_RO_SHIFT   16
#define XSYSMONPSV_SUPPLY_TH_LOWER_VAL_RO_WIDTH   3
#define XSYSMONPSV_SUPPLY_TH_LOWER_VAL_RO_MASK    0X00070000

#define XSYSMONPSV_SUPPLY_TH_LOWER_VAL_SHIFT   0
#define XSYSMONPSV_SUPPLY_TH_LOWER_VAL_WIDTH   16
#define XSYSMONPSV_SUPPLY_TH_LOWER_VAL_MASK    0X0000FFFF

/**
 * Register: XSYSMONPSV_SUPPLY_TH_UPPER
 */
#define XSYSMONPSV_SUPPLY_TH_UPPER    0X00001C80

#define XSYSMONPSV_SUPPLY_TH_UPPER_VAL_RO_SHIFT   16
#define XSYSMONPSV_SUPPLY_TH_UPPER_VAL_RO_WIDTH   3
#define XSYSMONPSV_SUPPLY_TH_UPPER_VAL_RO_MASK    0X00070000

#define XSYSMONPSV_SUPPLY_TH_UPPER_VAL_SHIFT   0
#define XSYSMONPSV_SUPPLY_TH_UPPER_VAL_WIDTH   16
#define XSYSMONPSV_SUPPLY_TH_UPPER_VAL_MASK    0X0000FFFF

/**
 * Register: XSYSMONPSV_NEW_DATA_INT_SRC
 */
#define XSYSMONPSV_NEW_DATA_INT_SRC     0X00001F80

#define XSYSMONPSV_INTR_NEW_DATA_MASK	0x0000F000
#define XSYSMONPSV_INTR_NEW_DATA_SHIFT	12

#define XSYSMONPSV_NEW_DATA_INT_SRC_ADDR_ID3_SHIFT   24
#define XSYSMONPSV_NEW_DATA_INT_SRC_ADDR_ID3_WIDTH   8
#define XSYSMONPSV_NEW_DATA_INT_SRC_ADDR_ID3_MASK    0XFF000000

#define XSYSMONPSV_NEW_DATA_INT_SRC_ADDR_ID2_SHIFT   16
#define XSYSMONPSV_NEW_DATA_INT_SRC_ADDR_ID2_WIDTH   8
#define XSYSMONPSV_NEW_DATA_INT_SRC_ADDR_ID2_MASK    0X00FF0000

#define XSYSMONPSV_NEW_DATA_INT_SRC_ADDR_ID1_SHIFT   8
#define XSYSMONPSV_NEW_DATA_INT_SRC_ADDR_ID1_WIDTH   8
#define XSYSMONPSV_NEW_DATA_INT_SRC_ADDR_ID1_MASK    0X0000FF00

#define XSYSMONPSV_NEW_DATA_INT_SRC_ADDR_ID0_SHIFT   0
#define XSYSMONPSV_NEW_DATA_INT_SRC_ADDR_ID0_WIDTH   8
#define XSYSMONPSV_NEW_DATA_INT_SRC_ADDR_ID0_MASK    0X000000FF

/**
 * Register: XSYSMONPSV_ALARM_CONFIG
 */
#define XSYSMONPSV_ALARM_CONFIG     0X00001F84

#define XSYSMONPSV_ALARM_CONFIG_DEV_ALARM_MODE_SHIFT   1
#define XSYSMONPSV_ALARM_CONFIG_DEV_ALARM_MODE_WIDTH   1
#define XSYSMONPSV_ALARM_CONFIG_DEV_ALARM_MODE_MASK    0X00000002

#define XSYSMONPSV_ALARM_CONFIG_OT_ALARM_MODE_SHIFT   0
#define XSYSMONPSV_ALARM_CONFIG_OT_ALARM_MODE_WIDTH   1
#define XSYSMONPSV_ALARM_CONFIG_OT_ALARM_MODE_MASK    0X00000001

/**
 * Register: XSYSMONPSV_I2C_STATUS
 */
#define XSYSMONPSV_I2C_STATUS     0X00001F88

#define XSYSMONPSV_I2C_STATUS_ADDRESSED_SHIFT   1
#define XSYSMONPSV_I2C_STATUS_ADDRESSED_WIDTH   1
#define XSYSMONPSV_I2C_STATUS_ADDRESSED_MASK    0X00000002

#define XSYSMONPSV_I2C_STATUS_BUS_BUSY_SHIFT   0
#define XSYSMONPSV_I2C_STATUS_BUS_BUSY_WIDTH   1
#define XSYSMONPSV_I2C_STATUS_BUS_BUSY_MASK    0X00000001

/**
 * Register: XSYSMONPSV_DEVICE_TEMP_MIN_MIN
 */
#define XSYSMONPSV_DEVICE_TEMP_MIN_MIN     0X00001F8C

#define XSYSMONPSV_DEVICE_TEMP_MIN_MIN_VAL_SHIFT   0
#define XSYSMONPSV_DEVICE_TEMP_MIN_MIN_VAL_WIDTH   16
#define XSYSMONPSV_DEVICE_TEMP_MIN_MIN_VAL_MASK    0X0000FFFF

/**
 * Register: XSYSMONPSV_DEVICE_TEMP_MAX_MAX
 */
#define XSYSMONPSV_DEVICE_TEMP_MAX_MAX     0X00001F90

#define XSYSMONPSV_DEVICE_TEMP_MAX_MAX_VAL_SHIFT   0
#define XSYSMONPSV_DEVICE_TEMP_MAX_MAX_VAL_WIDTH   16
#define XSYSMONPSV_DEVICE_TEMP_MAX_MAX_VAL_MASK    0X0000FFFF

/**
 * Register: XSYSMONPSV_STATUS_RESET
 */
#define XSYSMONPSV_STATUS_RESET     0X00001F94

#define XSYSMONPSV_STATUS_RESET_SUPPLY_SHIFT   1
#define XSYSMONPSV_STATUS_RESET_SUPPLY_WIDTH   1
#define XSYSMONPSV_STATUS_RESET_SUPPLY_MASK    0X00000002

#define XSYSMONPSV_STATUS_RESET_DEVICE_TEMP_SHIFT   0
#define XSYSMONPSV_STATUS_RESET_DEVICE_TEMP_WIDTH   1
#define XSYSMONPSV_STATUS_RESET_DEVICE_TEMP_MASK    0X00000001

/**
 * Register: XSYSMONPSV_GREF_STATUS
 */
#define XSYSMONPSV_GREF_STATUS     0X00001F98

#define XSYSMONPSV_GREF_STATUS_REF_SEL_SHIFT   1
#define XSYSMONPSV_GREF_STATUS_REF_SEL_WIDTH   4
#define XSYSMONPSV_GREF_STATUS_REF_SEL_MASK    0X0000001E

#define XSYSMONPSV_GREF_STATUS_EXT_REF_UP_SHIFT   0
#define XSYSMONPSV_GREF_STATUS_EXT_REF_UP_WIDTH   1
#define XSYSMONPSV_GREF_STATUS_EXT_REF_UP_MASK    0X00000001

/**
 * Register: XSYSMONPSV_AXI_CONFIG
 */
#define XSYSMONPSV_AXI_CONFIG     0X00001F9C

#define XSYSMONPSV_AXI_CONFIG_BUFFER_BASE_B48_SHIFT   24
#define XSYSMONPSV_AXI_CONFIG_BUFFER_BASE_B48_WIDTH   1
#define XSYSMONPSV_AXI_CONFIG_BUFFER_BASE_B48_MASK    0X01000000

#define XSYSMONPSV_AXI_CONFIG_SUPPLY_EN_SHIFT   23
#define XSYSMONPSV_AXI_CONFIG_SUPPLY_EN_WIDTH   1
#define XSYSMONPSV_AXI_CONFIG_SUPPLY_EN_MASK    0X00800000

#define XSYSMONPSV_AXI_CONFIG_VCCINT_EN_SHIFT   22
#define XSYSMONPSV_AXI_CONFIG_VCCINT_EN_WIDTH   1
#define XSYSMONPSV_AXI_CONFIG_VCCINT_EN_MASK    0X00400000

#define XSYSMONPSV_AXI_CONFIG_SLICE_TEMP_EN_SHIFT   21
#define XSYSMONPSV_AXI_CONFIG_SLICE_TEMP_EN_WIDTH   1
#define XSYSMONPSV_AXI_CONFIG_SLICE_TEMP_EN_MASK    0X00200000

#define XSYSMONPSV_AXI_CONFIG_TEMP_EN_SHIFT   20
#define XSYSMONPSV_AXI_CONFIG_TEMP_EN_WIDTH   1
#define XSYSMONPSV_AXI_CONFIG_TEMP_EN_MASK    0X00100000

#define XSYSMONPSV_AXI_CONFIG_AWLEN_SHIFT   12
#define XSYSMONPSV_AXI_CONFIG_AWLEN_WIDTH   8
#define XSYSMONPSV_AXI_CONFIG_AWLEN_MASK    0X000FF000

#define XSYSMONPSV_AXI_CONFIG_AWQOS_SHIFT   8
#define XSYSMONPSV_AXI_CONFIG_AWQOS_WIDTH   4
#define XSYSMONPSV_AXI_CONFIG_AWQOS_MASK    0X00000F00

#define XSYSMONPSV_AXI_CONFIG_AWBURST_SHIFT   6
#define XSYSMONPSV_AXI_CONFIG_AWBURST_WIDTH   2
#define XSYSMONPSV_AXI_CONFIG_AWBURST_MASK    0X000000C0

#define XSYSMONPSV_AXI_CONFIG_ENABLE_SHIFT   5
#define XSYSMONPSV_AXI_CONFIG_ENABLE_WIDTH   1
#define XSYSMONPSV_AXI_CONFIG_ENABLE_MASK    0X00000020

#define XSYSMONPSV_AXI_CONFIG_NUM_TRANS_SHIFT   0
#define XSYSMONPSV_AXI_CONFIG_NUM_TRANS_WIDTH   5
#define XSYSMONPSV_AXI_CONFIG_NUM_TRANS_MASK    0X0000001F

/**
 * Register: XSYSMONPSV_CLOCK_GATE_OR
 */
#define XSYSMONPSV_CLOCK_GATE_OR     0X00001FA0

#define XSYSMONPSV_CLOCK_GATE_OR_AXI_CG_OR_SHIFT   10
#define XSYSMONPSV_CLOCK_GATE_OR_AXI_CG_OR_WIDTH   1
#define XSYSMONPSV_CLOCK_GATE_OR_AXI_CG_OR_MASK    0X00000400

#define XSYSMONPSV_CLOCK_GATE_OR_PMBUS_CG_OR_SHIFT   7
#define XSYSMONPSV_CLOCK_GATE_OR_PMBUS_CG_OR_WIDTH   3
#define XSYSMONPSV_CLOCK_GATE_OR_PMBUS_CG_OR_MASK    0X00000380

#define XSYSMONPSV_CLOCK_GATE_OR_SYS_MEAS_CG_OR_SHIFT   5
#define XSYSMONPSV_CLOCK_GATE_OR_SYS_MEAS_CG_OR_WIDTH   2
#define XSYSMONPSV_CLOCK_GATE_OR_SYS_MEAS_CG_OR_MASK    0X00000060

#define XSYSMONPSV_CLOCK_GATE_OR_SPLY_MEAS_CG_OR_SHIFT   0
#define XSYSMONPSV_CLOCK_GATE_OR_SPLY_MEAS_CG_OR_WIDTH   5
#define XSYSMONPSV_CLOCK_GATE_OR_SPLY_MEAS_CG_OR_MASK    0X0000001F

/**
 * Register: XSYSMONPSV_VCCINT_FPD
 */
#define XSYSMONPSV_VCCINT_FPD     0X00001FA4

#define XSYSMONPSV_VCCINT_FPD_VAL_SHIFT   0
#define XSYSMONPSV_VCCINT_FPD_VAL_WIDTH   19
#define XSYSMONPSV_VCCINT_FPD_VAL_MASK    0X0007FFFF

/**
 * Register: XSYSMONPSV_VCCINT_LPD
 */
#define XSYSMONPSV_VCCINT_LPD     0X00001FA8

#define XSYSMONPSV_VCCINT_LPD_VAL_SHIFT   0
#define XSYSMONPSV_VCCINT_LPD_VAL_WIDTH   19
#define XSYSMONPSV_VCCINT_LPD_VAL_MASK    0X0007FFFF

/**
 * Register: XSYSMONPSV_TEMP_SAT
 */
#define XSYSMONPSV_TEMP_SAT     0X00001FAC

#define XSYSMONPSV_TEMP_SAT_VAL_SHIFT   0
#define XSYSMONPSV_TEMP_SAT_VAL_WIDTH   16
#define XSYSMONPSV_TEMP_SAT_VAL_MASK    0X0000FFFF

/**
 * Register: XSYSMONPSV_VCCINT_SAT
 */
#define XSYSMONPSV_VCCINT_SAT     0X000020A4

#define XSYSMONPSV_VCCINT_SAT_VAL_SHIFT   0
#define XSYSMONPSV_VCCINT_SAT_VAL_WIDTH   19
#define XSYSMONPSV_VCCINT_SAT_VAL_MASK    0X0007FFFF

/**
 * Register: XSYSMONPSV_SUPPLY_AVGCALC
 */
#define XSYSMONPSV_SUPPLY_AVGCALC     0X0000219C

#define XSYSMONPSV_SUPPLY_AVGCALC_SCOUNT_SHIFT   21
#define XSYSMONPSV_SUPPLY_AVGCALC_SCOUNT_WIDTH   4
#define XSYSMONPSV_SUPPLY_AVGCALC_SCOUNT_MASK    0X01E00000

#define XSYSMONPSV_SUPPLY_AVGCALC_RAVG_SHIFT   0
#define XSYSMONPSV_SUPPLY_AVGCALC_RAVG_WIDTH   21
#define XSYSMONPSV_SUPPLY_AVGCALC_RAVG_MASK    0X001FFFFF

/**
 * Register: XSYSMONPSV_SLICE_TEMP_MAX1
 */
#define XSYSMONPSV_SLICE_TEMP_MAX1     0X0000249C

#define XSYSMONPSV_SLICE_TEMP_MAX1_VAL_SHIFT   0
#define XSYSMONPSV_SLICE_TEMP_MAX1_VAL_WIDTH   16
#define XSYSMONPSV_SLICE_TEMP_MAX1_VAL_MASK    0X0000FFFF

/**
 * Register: XSYSMONPSV_SLICE_TEMP_MAX2
 */
#define XSYSMONPSV_SLICE_TEMP_MAX2     0X000024A0

#define XSYSMONPSV_SLICE_TEMP_MAX2_VAL_SHIFT   0
#define XSYSMONPSV_SLICE_TEMP_MAX2_VAL_WIDTH   16
#define XSYSMONPSV_SLICE_TEMP_MAX2_VAL_MASK    0X0000FFFF

/**
 * Register: XSYSMONPSV_SLICE_TEMP_MAX3
 */
#define XSYSMONPSV_SLICE_TEMP_MAX3     0X000024A4

#define XSYSMONPSV_SLICE_TEMP_MAX3_VAL_SHIFT   0
#define XSYSMONPSV_SLICE_TEMP_MAX3_VAL_WIDTH   16
#define XSYSMONPSV_SLICE_TEMP_MAX3_VAL_MASK    0X0000FFFF

/**
 * Register: XSYSMONPSV_SLICE_TEMP_MIN1
 */
#define XSYSMONPSV_SLICE_TEMP_MIN1     0X000024A8

#define XSYSMONPSV_SLICE_TEMP_MIN1_VAL_SHIFT   0
#define XSYSMONPSV_SLICE_TEMP_MIN1_VAL_WIDTH   16
#define XSYSMONPSV_SLICE_TEMP_MIN1_VAL_MASK    0X0000FFFF

/**
 * Register: XSYSMONPSV_SLICE_TEMP_MIN2
 */
#define XSYSMONPSV_SLICE_TEMP_MIN2     0X000024AC

#define XSYSMONPSV_SLICE_TEMP_MIN2_VAL_SHIFT   0
#define XSYSMONPSV_SLICE_TEMP_MIN2_VAL_WIDTH   16
#define XSYSMONPSV_SLICE_TEMP_MIN2_VAL_MASK    0X0000FFFF

/**
 * Register: XSYSMONPSV_SLICE_TEMP_MIN3
 */
#define XSYSMONPSV_SLICE_TEMP_MIN3     0X000024B0

#define XSYSMONPSV_SLICE_TEMP_MIN3_VAL_SHIFT   0
#define XSYSMONPSV_SLICE_TEMP_MIN3_VAL_WIDTH   16
#define XSYSMONPSV_SLICE_TEMP_MIN3_VAL_MASK    0X0000FFFF

/**
 * Register: XSYSMONPSV_EN_AVG_REG8
 */
#define XSYSMONPSV_EN_AVG_REG8     0X000024B4

#define XSYSMONPSV_EN_AVG_REG8_VAL_SHIFT   0
#define XSYSMONPSV_EN_AVG_REG8_VAL_WIDTH   32
#define XSYSMONPSV_EN_AVG_REG8_VAL_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_EN_AVG_REG9
 */
#define XSYSMONPSV_EN_AVG_REG9     0X000024B8

#define XSYSMONPSV_EN_AVG_REG9_VAL_SHIFT   0
#define XSYSMONPSV_EN_AVG_REG9_VAL_WIDTH   32
#define XSYSMONPSV_EN_AVG_REG9_VAL_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_SECURE_EFUSE_RDATA_LOW
 */
#define XSYSMONPSV_SECURE_EFUSE_RDATA_LOW     0X000024BC

#define XSYSMONPSV_SECURE_EFUSE_RDATA_LOW_VAL_SHIFT   0
#define XSYSMONPSV_SECURE_EFUSE_RDATA_LOW_VAL_WIDTH   32
#define XSYSMONPSV_SECURE_EFUSE_RDATA_LOW_VAL_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_SECURE_EFUSE_RDATA_HIGH
 */
#define XSYSMONPSV_SECURE_EFUSE_RDATA_HIGH     0X000024C0

#define XSYSMONPSV_SECURE_EFUSE_RDATA_HIGH_VAL_SHIFT   0
#define XSYSMONPSV_SECURE_EFUSE_RDATA_HIGH_VAL_WIDTH   32
#define XSYSMONPSV_SECURE_EFUSE_RDATA_HIGH_VAL_MASK    0XFFFFFFFF

/**
 * Register: XSYSMONPSV_AXI_STATUS
 */
#define XSYSMONPSV_AXI_STATUS     0X000024C4

#define XSYSMONPSV_AXI_STATUS_RESPONSE_SHIFT   6
#define XSYSMONPSV_AXI_STATUS_RESPONSE_WIDTH   2
#define XSYSMONPSV_AXI_STATUS_RESPONSE_MASK    0X000000C0

#define XSYSMONPSV_AXI_STATUS_TRANS_OUT_SHIFT   0
#define XSYSMONPSV_AXI_STATUS_TRANS_OUT_WIDTH   6
#define XSYSMONPSV_AXI_STATUS_TRANS_OUT_MASK    0X0000003F

/**
 * Register: XSYSMONPSV_AXI_PACKETS0
 */
#define XSYSMONPSV_AXI_PACKETS0     0X000024C8

#define XSYSMONPSV_AXI_PACKETS0_FILTERED_SHIFT   10
#define XSYSMONPSV_AXI_PACKETS0_FILTERED_WIDTH   10
#define XSYSMONPSV_AXI_PACKETS0_FILTERED_MASK    0X000FFC00

#define XSYSMONPSV_AXI_PACKETS0_DROPPED_SHIFT   0
#define XSYSMONPSV_AXI_PACKETS0_DROPPED_WIDTH   10
#define XSYSMONPSV_AXI_PACKETS0_DROPPED_MASK    0X000003FF

/**
 * Register: XSYSMONPSV_AXI_PACKETS1
 */
#define XSYSMONPSV_AXI_PACKETS1     0X000024CC

#define XSYSMONPSV_AXI_PACKETS1_INCOMING_SSC_MEAS_SHIFT   10
#define XSYSMONPSV_AXI_PACKETS1_INCOMING_SSC_MEAS_WIDTH   10
#define XSYSMONPSV_AXI_PACKETS1_INCOMING_SSC_MEAS_MASK    0X000FFC00

#define XSYSMONPSV_AXI_PACKETS1_OUTGOING_SHIFT   0
#define XSYSMONPSV_AXI_PACKETS1_OUTGOING_WIDTH   10
#define XSYSMONPSV_AXI_PACKETS1_OUTGOING_MASK    0X000003FF

/**
 * Register: XSYSMONPSV_AXI_PACKETS2
 */
#define XSYSMONPSV_AXI_PACKETS2     0X000024D0

#define XSYSMONPSV_AXI_PACKETS2_INCOMING_DEVICE_TEMP_MIN_SHIFT   10
#define XSYSMONPSV_AXI_PACKETS2_INCOMING_DEVICE_TEMP_MIN_WIDTH   10
#define XSYSMONPSV_AXI_PACKETS2_INCOMING_DEVICE_TEMP_MIN_MASK    0X000FFC00

#define XSYSMONPSV_AXI_PACKETS2_INCOMING_DEVICE_TEMP_MAX_SHIFT   0
#define XSYSMONPSV_AXI_PACKETS2_INCOMING_DEVICE_TEMP_MAX_WIDTH   10
#define XSYSMONPSV_AXI_PACKETS2_INCOMING_DEVICE_TEMP_MAX_MASK    0X000003FF

/**
 * Register: XSYSMONPSV_MEAS_PACKETS0
 */
#define XSYSMONPSV_MEAS_PACKETS0     0X000024D4

#define XSYSMONPSV_MEAS_PACKETS0_FILTERED_SHIFT   10
#define XSYSMONPSV_MEAS_PACKETS0_FILTERED_WIDTH   10
#define XSYSMONPSV_MEAS_PACKETS0_FILTERED_MASK    0X000FFC00

#define XSYSMONPSV_MEAS_PACKETS0_DROPPED_SHIFT   0
#define XSYSMONPSV_MEAS_PACKETS0_DROPPED_WIDTH   10
#define XSYSMONPSV_MEAS_PACKETS0_DROPPED_MASK    0X000003FF

/**
 * Register: XSYSMONPSV_MEAS_PACKETS1
 */
#define XSYSMONPSV_MEAS_PACKETS1     0X000024D8

#define XSYSMONPSV_MEAS_PACKETS1_INCOMING_APB_SHIFT   10
#define XSYSMONPSV_MEAS_PACKETS1_INCOMING_APB_WIDTH   10
#define XSYSMONPSV_MEAS_PACKETS1_INCOMING_APB_MASK    0X000FFC00

#define XSYSMONPSV_MEAS_PACKETS1_OUTGOING_SHIFT   0
#define XSYSMONPSV_MEAS_PACKETS1_OUTGOING_WIDTH   10
#define XSYSMONPSV_MEAS_PACKETS1_OUTGOING_MASK    0X000003FF

/**
 * Register: XSYSMONPSV_MEAS_PACKETS2
 */
#define XSYSMONPSV_MEAS_PACKETS2     0X000024DC

#define XSYSMONPSV_MEAS_PACKETS2_INCOMING_SAT1_SHIFT   10
#define XSYSMONPSV_MEAS_PACKETS2_INCOMING_SAT1_WIDTH   10
#define XSYSMONPSV_MEAS_PACKETS2_INCOMING_SAT1_MASK    0X000FFC00

#define XSYSMONPSV_MEAS_PACKETS2_INCOMING_SAT0_SHIFT   0
#define XSYSMONPSV_MEAS_PACKETS2_INCOMING_SAT0_WIDTH   10
#define XSYSMONPSV_MEAS_PACKETS2_INCOMING_SAT0_MASK    0X000003FF

/**
 * Register: XSYSMONPSV_MEAS_PACKETS3
 */
#define XSYSMONPSV_MEAS_PACKETS3     0X000024E0

#define XSYSMONPSV_MEAS_PACKETS3_INCOMING_LPD_SHIFT   10
#define XSYSMONPSV_MEAS_PACKETS3_INCOMING_LPD_WIDTH   10
#define XSYSMONPSV_MEAS_PACKETS3_INCOMING_LPD_MASK    0X000FFC00

#define XSYSMONPSV_MEAS_PACKETS3_INCOMING_FPD_SHIFT   0
#define XSYSMONPSV_MEAS_PACKETS3_INCOMING_FPD_WIDTH   10
#define XSYSMONPSV_MEAS_PACKETS3_INCOMING_FPD_MASK    0X000003FF

/**
 * Register: XSYSMONPSV_MEAS_PACKETS4
 */
#define XSYSMONPSV_MEAS_PACKETS4     0X000024E4

#define XSYSMONPSV_MEAS_PACKETS4_INCOMING_PL_SHIFT   0
#define XSYSMONPSV_MEAS_PACKETS4_INCOMING_PL_WIDTH   10
#define XSYSMONPSV_MEAS_PACKETS4_INCOMING_PL_MASK    0X000003FF

/**
 * Register: XSYSMONPSV_STATUS_ENABLE
 */
#define XSYSMONPSV_STATUS_ENABLE     0X000024E8

#define XSYSMONPSV_STATUS_ENABLE_PACKETS_SHIFT   0
#define XSYSMONPSV_STATUS_ENABLE_PACKETS_WIDTH   1
#define XSYSMONPSV_STATUS_ENABLE_PACKETS_MASK    0X00000001

/**
 * Register: XSYSMONPSV_SSC_MEASURE_IF
 */
#define XSYSMONPSV_SSC_MEASURE_IF     0X00004000

#define XSYSMONPSV_SSC_MEASURE_IF_MEAS_VALID_SHIFT   28
#define XSYSMONPSV_SSC_MEASURE_IF_MEAS_VALID_WIDTH   1
#define XSYSMONPSV_SSC_MEASURE_IF_MEAS_VALID_MASK    0X10000000

#define XSYSMONPSV_SSC_MEASURE_IF_MEAS_ID_SHIFT   19
#define XSYSMONPSV_SSC_MEASURE_IF_MEAS_ID_WIDTH   9
#define XSYSMONPSV_SSC_MEASURE_IF_MEAS_ID_MASK    0X0FF80000

#define XSYSMONPSV_SSC_MEASURE_IF_MEAS_DATA_SHIFT   0
#define XSYSMONPSV_SSC_MEASURE_IF_MEAS_DATA_WIDTH   19
#define XSYSMONPSV_SSC_MEASURE_IF_MEAS_DATA_MASK    0X0007FFFF

/***************** Macros (Inline Functions) Definitions *********************/

/****************************************************************************/
/**
*
* This macro reads the given register.
*
* @param	RegisterAddr is the register address in the address
*		space of the SYSMONPSV device.
*
* @return	The 32-bit value of the register
*
* @note		None.
*
*****************************************************************************/
#define XSysMonPsv_ReadReg(RegisterAddr) Xil_In32(RegisterAddr)

/****************************************************************************/
/**
*
* This macro writes the given register.
*
* @param	RegisterAddr is the register address in the address
*		space of the SYSMONPSV device.
* @param	Data is the 32-bit value to write to the register.
*
* @return	None.
*
* @note		None.
*
*****************************************************************************/
#define XSysMonPsv_WriteReg(RegisterAddr, Data)			\
				Xil_Out32(RegisterAddr, (u32)(Data))

#ifdef __cplusplus
}
#endif


#endif /* XSYSMONPSV_HW_H_ */
